<?php
namespace App\Controller;

use App\Controller\AppController;

/**
 * Depositos Controller
 *
 * @property \App\Model\Table\DepositosTable $Depositos
 *
 * @method \App\Model\Entity\Deposito[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class DepositosController extends AppController
{

    /**
     * Index method
     *
     * @return \Cake\Http\Response|void
     */
    public function index()
    {
        $depositos = $this->paginate($this->Depositos);

        $this->set(compact('depositos'));
    }

    /**
     * View method
     *
     * @param string|null $id Deposito id.
     * @return \Cake\Http\Response|void
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $deposito = $this->Depositos->get($id, [
            'contain' => ['Ubicas']
        ]);

        $this->set('deposito', $deposito);
    }

    /**
     * Add method
     *
     * @return \Cake\Http\Response|null Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        $deposito = $this->Depositos->newEntity();
        if ($this->request->is('post')) {
            $deposito = $this->Depositos->patchEntity($deposito, $this->request->getData());
            if ($this->Depositos->save($deposito)) {
                $this->Flash->success(__('The deposito has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The deposito could not be saved. Please, try again.'));
        }
        $ubicas = $this->Depositos->Ubicas->find('list', ['limit' => 200]);
        $this->set(compact('deposito', 'ubicas'));
    }

    /**
     * Edit method
     *
     * @param string|null $id Deposito id.
     * @return \Cake\Http\Response|null Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $deposito = $this->Depositos->get($id, [
            'contain' => ['Ubicas']
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $deposito = $this->Depositos->patchEntity($deposito, $this->request->getData());
            if ($this->Depositos->save($deposito)) {
                $this->Flash->success(__('The deposito has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The deposito could not be saved. Please, try again.'));
        }
        $ubicas = $this->Depositos->Ubicas->find('list', ['limit' => 200]);
        $this->set(compact('deposito', 'ubicas'));
    }

    /**
     * Delete method
     *
     * @param string|null $id Deposito id.
     * @return \Cake\Http\Response|null Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $deposito = $this->Depositos->get($id);
        if ($this->Depositos->delete($deposito)) {
            $this->Flash->success(__('The deposito has been deleted.'));
        } else {
            $this->Flash->error(__('The deposito could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }
}
