<?php

namespace App\Controller;

use App\Controller\AppController;
use Cake\ORM\TableRegistry;
use Cake\Datasource\ConnectionManager;
use Cake\I18n\Time;

class StocksController extends AppController
{

    public function initialize()
    {
        parent::initialize();
        $this->loadComponent('RequestHandler');
        $this->loadComponent('Paginator');
        $this->loadModel('Franquiciastocks');
    }


    public function beforeFilter(\Cake\Event\Event $event)
    {
        parent::beforeFilter($event);
        $this->Auth->allow(['addkilometraje', 'addtipollanta']);
    }

    public function index()
    {

        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    )
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $this->set('stocks', $this->paginate($stocks));
            $this->set('_serialize', ['stocks']);
        } else {
            $this->paginate = [
                'order' => [
                    'Stocks.modelo' => 'asc'
                ]
            ];
            $stocks = $this->paginate($this->Stocks);
            $this->set(compact('stocks'));
            $this->set('_serialize', ['stocks']);
        }
        $this->set('search', $search);
    }

    ////
    public function franquicia()
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('chasis LIKE' => '%' . $term . '%'),
                        array('modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('color LIKE' => '%' . strtoupper($term) . '%'),
                        array('ano LIKE' => '%' . strtoupper($term) . '%'),
                    )
                );
            }
            $stocks = $this->Franquiciastocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['modelo' => 'asc']));
            $this->set('stocks', $this->paginate($stocks));
            $this->set('_serialize', ['stocks']);
        } else {
            $this->paginate = [
                'order' => [
                    'modelo' => 'asc'
                ]
            ];
            $stocks = $this->Paginator->paginate($this->Franquiciastocks->find('all'));
            $this->set(compact('stocks'));
            $this->set('_serialize', ['stocks']);
        }
        $this->set('search', $search);
    }

    ////    

    public function faltafoto()
    {

        $this->paginate = [
            'conditions' => ['stocks.imagen IS NULL'],
            'order' => [
                'Stocks.estado' => 'asc',
                'Stocks.modelo' => 'asc'
            ]
        ];

        $stocks = $this->paginate($this->Stocks);

        $this->set(compact('stocks'));
        $this->set('_serialize', ['stocks']);
    }

    public function indexventa()
    {

        $this->paginate = [
            'order' => [
                'Stocks.modelo' => 'asc'
            ]
        ];

        $stocks = $this->paginate($this->Stocks);

        $this->set(compact('stocks'));
        $this->set('_serialize', ['stocks']);
    }

    public function mostrar($chasis = null)
    {
        $imagenapps  =  TableRegistry::get('imagenapps');
        $imagens =  $imagenapps->find();
        $imagens->where(['chasis' => '' . $chasis . '']);
        // $imagens->where(['chasis' => $chasis, 'mostrar' => 1]);
        $imagens->order(['mostrar', 'id']);
        $this->set('imagen',  $imagens);
    }


    public function todoimagen()
    {
        $this->paginate = [
            'order' => [
                'Stocks.modelo' => 'asc'
            ]
        ];
        $stocks = $this->paginate($this->Stocks);
        $this->set(compact('stocks'));
        $this->set('_serialize', ['stocks']);
    }

    public function view($id = null)
    {
        $stock = $this->Stocks->get($id, []);
        $this->set(compact('stock', 'cotizacions'));

        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti) :
            $venta = $coti->doven;
            $compra = $coti->docom;
        endforeach;
        $this->set('cotizacionventa',  $venta);

        $precioespecials = TableRegistry::get('preciocreditos');
        $precioEspecial = $precioespecials
            ->find()
            ->where([
                'modelo' => $stock->modelo,
                'ano_desde <=' => $stock->ano,
                'ano_hasta >=' => $stock->ano,
                'carroceria' => $stock->carroceria,
                'borrado' => 0
            ])
            ->first();

        if (!empty($stock->vendedorsena)) {

            $empleados = TableRegistry::get('empleados')->find()
                ->where([
                    'id' => $stock->vendedorsena
                ])
                ->first();

            $this->set('vendedors', $empleados);
        }


        $this->set('preciocreditos', $precioEspecial);

        $this->set('_serialize', ['stock']);
    }

    ////
    public function viewfranquicia($id = null)
    {
        $stock = $this->Franquiciastocks->get($id, []);
        $this->set(compact('stock', 'cotizacions'));

        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti) :
            $venta = $coti->doven;
            $compra = $coti->docom;
        endforeach;
        $this->set('cotizacionventa',  $venta);

        $precioespecials = TableRegistry::get('preciocreditos');
        $precioEspecial = $precioespecials
            ->find()
            ->where([
                'modelo' => $stock->modelo,
                'ano_desde <=' => $stock->ano,
                'ano_hasta >=' => $stock->ano,
                'carroceria' => $stock->carroceria,
                'borrado' => 0
            ])
            ->first();

        if (!empty($stock->vendedorsena)) {

            $empleados = TableRegistry::get('empleados')->find()
                ->where([
                    'id' => $stock->vendedorsena
                ])
                ->first();

            $this->set('vendedors', $empleados);
        }


        $this->set('preciocreditos', $precioEspecial);

        $this->set('_serialize', ['stock']);
    }
    ////

    public function mostrarprecio($id = null)
    {
        if ($this->request->is('post')) {
            $stock = $this->Stocks->newEntity();
            $stock = $this->Stocks->patchEntity($stock, $this->request->data);

            $connection = ConnectionManager::get('default');
            $connection->execute('UPDATE productos SET  pro_mostrarultimoprecio=?, pro_aumentargenerente1=?, pro_aumentargenerente2=?, pro_aumentargenerente3=? WHERE pro_codigo=?', [$stock->mostrarprecio, $stock->aumentargenerente1, $stock->aumentargenerente2, $stock->aumentargenerente3, $id]);
            $connection->commit();
            $connection->disconnect();

            echo "<script>history.go(-2)</script>";
        }
        $stock = $this->Stocks->get($id, []);
        $this->set(compact('stock'));
    }


    public function viewrichard($id = null)
    {
        $stock = $this->Stocks->get($id, []);

        $this->set(compact('stock', 'cotizacions'));
        $this->set('_serialize', ['stock']);
    }

    public function chasis($chasis = null)
    {
        $tocks  =  TableRegistry::get('stocks');
        $query = $tocks->find('all', ['conditions' => ['stocks.chasis LIKE' => '%' . $chasis . '%']]);
        $this->set('stocks', $query);
    }

    public function aprobacion($id = null)
    {
        $keymoneda = 0;
        if (!empty($this->request->query('comboMoneda'))) {
            $keymoneda = $this->request->query('comboMoneda');
        }

        $keyentrega = 0;
        if (!empty($this->request->query('txtEntrega'))) {
            $keyentrega = $this->request->query('txtEntrega');
        }

        $keyentregav = 0;
        if (!empty($this->request->query('txtEntregave'))) {
            $keyentregav = $this->request->query('txtEntregave');
        }

        $keycambalache = 0;
        if (!empty($this->request->query('txtCambalache'))) {
            $keycambalache = $this->request->query('txtCambalache');
        }

        $keycantrefuerzo = 0;
        if (!empty($this->request->query('txtCantidadRefuerzo'))) {
            $keycantrefuerzo = $this->request->query('txtCantidadRefuerzo');
        }

        $keyrefuerzo = 0;
        if (!empty($this->request->query('txtRefuerzo'))) {
            $keyrefuerzo = $this->request->query('txtRefuerzo');
        }

        $keyplazp = 0;
        if (!empty($this->request->query('comboPlazo'))) {
            $keyplazo = $this->request->query('comboPlazo');
        }


        echo   $keyword2 . ' - '  . $keyword3 . ' - '  . $keyword4 . ' - '  . $keyword5 . ' - '  . $keyword6 . ' - ' . $keyword7 . ' - ' . $keyword8;

        if (!empty($this->request->query['cedula'])) {

            $hoy = getdate();
            $fecha = $hoy['mday'] . "/" . $hoy['mon'] . "/" . $hoy['year'];
            $empleado = $this->Auth->User('empleado');
            $cedula = $this->request->query['cedula'];
            $telefono = $this->request->query['telefono'];

            $bonos  =  TableRegistry::get('simulador_ventas');
            $querybonos =  $bonos->find('all', ['conditions' => ['empleado_id' => $empleado, 'producto_id' => $id, 'borrado = 0', "fecha = '" . $fecha .  "'", 'ci' => $cedula, 'telefono' => $telefono]]);

            $this->set('querybonos',  $querybonos);

            $sw = 0;
            $cantidad = 0;
            $vecesss = 1;
            foreach ($querybonos as $bono) :
                $sw = 1;
                $cantidad = $bono->totalbono;
                $vecesss = $bono->veces + 1;
            endforeach;

            $this->set('retro',  $vecesss);

            if ($sw == 0) {
                if ($this->request->is('get')) {
                    $numero = mt_rand(1, 3);

                    if ($numero == 1) {
                        $bonoprimer = 250;
                    }

                    if ($numero == 2) {
                        $bonoprimer = 150;
                    }

                    if ($numero == 3) {
                        $bonoprimer = 100;
                    }


                    $bonosventa  =  TableRegistry::get('simulador_ventas');

                    $bonosventa->producto_id = $id;
                    $bonosventa->meses = 0;
                    $bonosventa->moneda = 0;
                    $bonosventa->total = 0;
                    $bonosventa->entrega = 0;
                    $bonosventa->saldo = 0;
                    $bonosventa->cuota = 0;
                    $bonosventa->montocuota = 0;
                    $bonosventa->refuerzo = 0;
                    $bonosventa->montorefuerzo = 0;
                    $bonosventa->chasis = "";
                    $bonosventa->empleado_id = $empleado;
                    $bonosventa->fecha = $fecha;
                    $bonosventa->hora = date("H:i:s");
                    $bonosventa->tipopersona = 0;
                    $bonosventa->ci = $cedula;
                    $bonosventa->telefono = $telefono;
                    $bonosventa->aleatorio = $numero;
                    $bonosventa->veces = 1;
                    $bonosventa->vecesgerente = 0;
                    $bonosventa->vecessergio = 0;
                    $bonosventa->estado = 0;
                    $bonosventa->borrado = 0;
                    $bonosventa->confirmado = 0;
                    $bonosventa->totalbono = $bonoprimer;

                    $querysimulador = TableRegistry::get('simulador_ventas')->query();

                    $querysimulador->insert(['chasis', 'producto_id', 'meses', 'moneda', 'total', 'entrega', 'saldo', 'cuota', 'montocuota', 'refuerzo', 'montorefuerzo', 'empleado_id', 'fecha', 'hora', 'tipopersona', 'ci', 'telefono', 'aleatorio', 'veces', 'vecesgerente', 'vecessergio', 'estado', 'borrado', 'confirmado', 'totalbono'])->values([
                        'chasis' => $bonosventa->chasis,
                        'producto_id' => $bonosventa->producto_id,
                        'meses' => $bonosventa->meses,
                        'moneda' => $bonosventa->moneda,
                        'total' => $bonosventa->total,
                        'entrega' => $bonosventa->entrega,
                        'saldo' => $bonosventa->saldo,
                        'cuota' => $bonosventa->cuota,
                        'montocuota' => $bonosventa->montocuota,
                        'refuerzo' => $bonosventa->refuerzo,
                        'montorefuerzo' => $bonosventa->montorefuerzo,
                        'empleado_id' => $bonosventa->empleado_id,
                        'fecha' => $bonosventa->fecha,
                        'hora' => $bonosventa->hora,
                        'tipopersona' => $bonosventa->tipopersona,
                        'ci' => $bonosventa->ci,
                        'telefono' => $bonosventa->telefono,
                        'aleatorio' => $bonosventa->aleatorio,
                        'veces' => $bonosventa->veces,
                        'vecesgerente' => $bonosventa->vecesgerente,
                        'vecessergio' => $bonosventa->vecessergio,
                        'estado' => $bonosventa->estado,
                        'borrado' => $bonosventa->borrado,
                        'confirmado' => $bonosventa->confirmado,
                        'totalbono' => $bonosventa->totalbono
                    ])->execute();
                }
            } else {

                echo $this->request->is('post');
            }

            $stock = $this->Stocks->get($id, []);
            $this->set(compact('stock'));
        } else {
            $stock = $this->Stocks->get($id, []);
            $this->set(compact('stock'));
            $this->set('querybonos',  "");
        }
    }

    public function aprobacion2($id = null)
    {

        $this->request->allowMethod('ajax');

        $keyword = $this->request->query('keyword');

        $stock = $this->Stocks->get($id, []);

        $hoy = getdate();
        $fecha = $hoy['mday'] . "/" . $hoy['mon'] . "/" . $hoy['year'];
        $empleado = $this->Auth->User('empleado');
        $bonos  =  TableRegistry::get('bonos');
        $querybonos =  $bonos->find('all');
        $querybonos->where(['empleado_id' => $empleado, 'stock_id' => $id, 'fecha' => '' . $fecha . '', 'activo' => 0]);
        $this->set('bonos',  $querybonos);

        $this->set(compact('stock', 'cotizacions'));
        $this->set('_serialize', ['stock']);
    }

    public function simuladorcuota($id = null)
    {
        $stock = $this->Stocks->get($id, []);
        $this->set(compact('stocks', 'stock'));
        $this->set('_serialize', ['stock']);
    }


    public function simuladornew($id = null)
    {
        $stock = $this->Stocks->get($id, []);

        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti) :
            $venta = $coti->doven;
            $compra = $coti->docom;
        endforeach;

        $this->set('cotiventa', $venta);
        $this->set('coticompra', $compra);

        $this->set(compact('stocks', 'stock'));
        $this->set('_serialize', ['stock']);
        $this->set("cotizacion", $query->first());
    }


    public function simuladorcredito($id = null)
    {
        $stock = $this->Stocks->get($id, []);

        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti) :
            $venta = $coti->doven;
            $compra = $coti->docom;
        endforeach;

        $this->set('cotiventa', $venta);
        $this->set('coticompra', $compra);

        $this->set(compact('stocks', 'stock'));
        $this->set('_serialize', ['stock']);
        $this->set("cotizacion", $query->first());
    }


    public function simuladorcontado($id = null)
    {
        $stock = $this->Stocks->get($id, []);

        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti) :
            $venta = $coti->doven;
            $compra = $coti->docom;
        endforeach;

        $this->set('cotiventa', $venta);
        $this->set('coticompra', $compra);
        $this->set(compact('stocks', 'stock'));
        $this->set('_serialize', ['stock']);
        $this->set("cotizacion", $query->first());
    }


    public function view2($id = null)
    {
        $stock = $this->Stocks->get($id, []);

        $this->set(compact('stocks', 'stock'));
        $this->set('_serialize', ['stock']);
    }

    public function banco($id = null)
    {
        $stock = $this->Stocks->get($id, []);
        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        foreach ($query as $coti) :
            $venta = $coti->doven;
        endforeach;
        $this->set('cotizacion', $venta);
        $this->set(compact('stocks', 'stock'));
        $this->set('_serialize', ['stock']);
    }

    public function cuotabanco($id = null)
    {
        $stock = $this->Stocks->get($id, []);
        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        foreach ($query as $coti) :
            $venta = $coti->doven;
        endforeach;

        $this->set('cotizacion', $venta);
        $this->set(compact('stock', 'cotizacion'));
        $this->set('_serialize', ['stock']);
    }

    public function view3($id = null)
    {
        $stock = $this->Stocks->get($id, []);
        $this->set(compact('stock', 'cotizacions'));
        $this->set('_serialize', ['stock']);
    }

    public function add()
    {
        $stock = $this->Stocks->newEntity();
        if ($this->request->is('post')) {
            $stock = $this->Stocks->patchEntity($stock, $this->request->data);
            if ($this->Stocks->save($stock)) {
                $this->Flash->success(__('The stock has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The stock could not be saved. Please, try again.'));
        }
        $this->set(compact('stock'));
        $this->set('_serialize', ['stock']);
    }

    public function edit($id = null)
    {
        $stock = $this->Stocks->get($id, [
            'contain' => []
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $stock = $this->Stocks->patchEntity($stock, $this->request->data);
            if ($this->Stocks->save($stock)) {
                $this->Flash->success(__('The stock has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The stock could not be saved. Please, try again.'));
        }
        $this->set(compact('stock'));
        $this->set('_serialize', ['stock']);
    }

    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $stock = $this->Stocks->get($id);
        if ($this->Stocks->delete($stock)) {
            $this->Flash->success(__('The stock has been deleted.'));
        } else {
            $this->Flash->error(__('The stock could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }


    public function recienimportados()
    {
        $conditions =  "Stocks.estado = 'RECIEN IMPORTADO'";
        $stocks = $this->Stocks->find('all', array('conditions' => $conditions, 'order' => ['Stocks.modelo' => 'asc']));
        $this->set('stocks', $stocks);
    }


    public function usados()
    {
        $conditions =  "Stocks.estado = 'USADO'";
        $stocks = $this->Stocks->find('all', array('conditions' => $conditions, 'order' => ['Stocks.modelo' => 'asc']));
        $this->set('stocks', $stocks);
    }

    public function recuperados()
    {
        $conditions =  "Stocks.estado = 'RECUPERADO'";
        $stocks = $this->Stocks->find('all', array('conditions' => $conditions, 'order' => ['Stocks.modelo' => 'asc']));
        $this->set('stocks', $stocks);
    }

    public function solocontado()
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    ),
                    array('Stocks.solocontado' => 1)
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $this->set('stocks', $this->paginate($stocks));
            $this->set('_serialize', ['stocks']);
        } else {

            // $conditions =  "Stocks.solocontado = 1";
            // $stocks = $this->Stocks->find('all', array('conditions' => $conditions, 'order' => ['Stocks.modelo' => 'asc']));
            // $this->set('stocks', $stocks);
            // // luismoran
            // $this->set('stocks', $this->paginate($stocks));
            // $this->set('_serialize', ['stocks']);

            $this->paginate = [
                'conditions' => [
                    'Stocks.solocontado' => 1
                ],
                'order' => [
                    'Stocks.modelo' => 'asc'
                ]
            ];
            $this->set('stocks', $this->paginate($this->Stocks));
            $this->set('_serialize', ['stocks']);
        }

        $this->set('search', $search);
    }

    public function recienimportado()
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    ),
                    array('stocks.estado LIKE' => 'RECIEN IMPORTADO', 'Stocks.solocontado' => 0)
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $this->set('stocks', $this->paginate($stocks));
            $this->set('_serialize', ['stocks']);
        } else {
            $this->paginate = [
                'conditions' => [
                    'Stocks.estado' => 'RECIEN IMPORTADO',
                    'Stocks.solocontado' => 0
                ],
                'order' => [
                    'Stocks.modelo' => 'asc'
                ]
            ];
            $this->set('stocks', $this->paginate($this->Stocks));
            $this->set('_serialize', ['stocks']);
        }
        $this->set('search', $search);
    }


    public function cerokm()
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    ),
                    array('stocks.estado LIKE' => '0 KM', 'Stocks.solocontado' => 0)
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $this->set('stocks', $this->paginate($stocks));
            $this->set('_serialize', ['stocks']);
        } else {
            $this->paginate = [
                'conditions' => [
                    'Stocks.estado' => '0 KM',
                    'Stocks.solocontado' => 0
                ],
                'order' => [
                    'Stocks.modelo' => 'asc'
                ]
            ];
            $this->set('stocks', $this->paginate($this->Stocks));
            $this->set('_serialize', ['stocks']);
        }
        $this->set('search', $search);
    }


    public function usado()
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 .]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    ),
                    array('stocks.estado LIKE' => 'USADO', 'Stocks.solocontado' => 0)
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $this->set('stocks', $this->paginate($stocks));
            $this->set('_serialize', ['stocks']);
        } else {
            $this->paginate = [
                'conditions' => [
                    'Stocks.estado' => 'USADO',
                    'Stocks.solocontado' => 0
                ],
                'order' => [
                    'Stocks.modelo' => 'asc'
                ]
            ];
            $this->set('stocks', $this->paginate($this->Stocks));
            $this->set('_serialize', ['stocks']);
        }
        $this->set('search', $search);
    }

    public function senado()
    {
        $this->paginate = [
            'conditions' => [
                'Stocks.sena' => 'SI',
            ],
            'order' => [
                'Stocks.modelo' => 'asc'
            ]
        ];
        $this->set('stocks', $this->paginate($this->Stocks));
        $this->set('_serialize', ['stocks']);
    }

    public function recuperado()
    {

        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    ),
                    array('stocks.estado LIKE' => 'RECUPERADO', 'Stocks.solocontado' => 0, 'Stocks.secuestrado' => 0)
                );
            }

            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $this->set('stocks', $this->paginate($stocks));
            $this->set('_serialize', ['stocks']);
        } else {
            $this->paginate = [
                'conditions' => [
                    'Stocks.estado' => 'RECUPERADO',
                    'Stocks.solocontado' => 0,
                    'Stocks.secuestrado' => 0
                ],
                'order' => [
                    'Stocks.modelo' => 'asc'
                ]
            ];
            $this->set('stocks', $this->paginate($this->Stocks));
            $this->set('_serialize', ['stocks']);
        }
        $this->set('search', $search);
    }

    public function search()
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    )
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $terms1 = array_diff($terms1, array(''));
            $this->set(compact('stocks', 'terms1'));
            if ($this->request->is('ajax')) {
                $this->layout = true;
                $this->set('ajax', 1);
            } else {
                $this->set('ajax', 0);
            }
        } else {
            return $this->redirect(['action' => 'index']);
        }
    }

    public function search2()
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    ),
                    array('stocks.estado LIKE' => 'RECIEN IMPORTADO')
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $terms1 = array_diff($terms1, array(''));
            $this->set(compact('stocks', 'terms1'));
            if ($this->request->is('ajax')) {
                $this->layout = true;
                $this->set('ajax', 1);
            } else {
                $this->set('ajax', 0);
            }
        } else {
            return $this->redirect(['action' => 'recienimportado']);
        }
    }

    public function search6()
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    ),
                    array('stocks.sena LIKE' => 'SI')
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $terms1 = array_diff($terms1, array(''));
            $this->set(compact('stocks', 'terms1'));
            if ($this->request->is('ajax')) {
                $this->layout = true;
                $this->set('ajax', 1);
            } else {
                $this->set('ajax', 0);
            }
        } else {
            return $this->redirect(['action' => 'senado']);
        }
    }

    public function search3()
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    ),
                    array('stocks.estado LIKE' => 'USADO')
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $terms1 = array_diff($terms1, array(''));
            $this->set(compact('stocks', 'terms1'));
            if ($this->request->is('ajax')) {
                $this->layout = true;
                $this->set('ajax', 1);
            } else {
                $this->set('ajax', 0);
            }
        } else {
            return $this->redirect(['action' => 'usado']);
        }
    }

    public function search4()
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    ),
                    array('stocks.estado LIKE' => 'RECUPERADO')
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $terms1 = array_diff($terms1, array(''));
            $this->set(compact('stocks', 'terms1'));
            if ($this->request->is('ajax')) {
                $this->layout = true;
                $this->set('ajax', 1);
            } else {
                $this->set('ajax', 0);
            }
        } else {
            return $this->redirect(['action' => 'recuperado']);
        }
    }


    public function deportivo()
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $terms = explode(' ', $search); // Generar los términos de búsqueda
            foreach ($terms as $term) {
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    ),
                    array('stocks.deportivo LIKE' => 'ES DEPORTIVO')
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $this->set(compact('stocks', 'terms1'));
        } else {
            $this->paginate = [
                'conditions' => [
                    'Stocks.deportivo' => 'ES DEPORTIVO',
                ],
                'order' => [
                    'Stocks.modelo' => 'asc'
                ]
            ];
            $this->set('stocks', $this->paginate($this->Stocks));
            $this->set('_serialize', ['stocks']);
        }
        $this->set('search', $search);
    }


    public function secuestrado($stock = null)
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $terms = explode(' ', $search); // Generar los términos de búsqueda

            $conditions = array();
            foreach ($terms as $term) {
                $conditions[] = array(
                    'OR' => array(
                        array('stocktodos.chasis LIKE' => '%' . $term . '%'),
                        array('stocktodos.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocktodos.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocktodos.ano LIKE' => '%' . strtoupper($term) . '%'),
                    ),
                    array('stocktodos.secuestrado' => 1),
                    array('stocktodos.stock' => $stock)
                );
            }


            ///debug($conditions); exit();
            $Secuestrado  =  TableRegistry::get('stocktodos');
            $stocks = $Secuestrado->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['stocktodos.modelo' => 'asc']));

            $this->set(compact('stocks', 'terms1'));

            $this->set('search', $search);
        } else {
            $this->paginate = [
                'conditions' => [
                    'stocktodos.secuestrado' => 1,
                    'stocktodos.stock' => $stock
                ],
                'order' => [
                    'stocktodos.modelo' => 'asc'
                ]
            ];
            $Secuestrado  =  TableRegistry::get('stocktodos');
            $this->set('stocks', $this->paginate($Secuestrado));
            $this->set('_serialize', ['stocks']);
            $this->set('search', "");
        }
        $this->set('search', $search);
        $this->set('stocktipo', $stock);
    }

    public function nodisponibles()
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];

            foreach ($terms as $term) {
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    ),
                    array('stocks.disponible' => 1)
                );
            }
            $Secuestrado  =  TableRegistry::get('stocks');
            $stocks = $Secuestrado->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['stocks.modelo' => 'asc']));
            $this->set(compact('stocks', 'terms1'));
        } else {
            $this->paginate = [
                'conditions' => [
                    'stocks.disponible' => 1,
                ],
                'order' => [
                    'stocks.modelo' => 'asc'
                ]
            ];
            $Secuestrado  =  TableRegistry::get('stocks');
            $this->set('stocks', $this->paginate($Secuestrado));
            $this->set('_serialize', ['stocks']);
        }
        $this->set('search', $search);
    }

    public function llanta()
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $terms = explode(' ', $search); // Generar los términos de búsqueda

            foreach ($terms as $term) {
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    )
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions . "' AND stocks.llanta' = 'TIENE LLANTA DEPORTIVA'", 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $this->set(compact('stocks', 'terms1'));
        } else {
            $this->paginate = [
                'conditions' => [
                    'Stocks.llanta' => 'TIENE LLANTA DEPORTIVA',
                ],
                'order' => [
                    'Stocks.modelo' => 'asc'
                ]
            ];
            $this->set('stocks', $this->paginate($this->Stocks));
            $this->set('_serialize', ['stocks']);
        }
        $this->set('search', $search);
    }


    public function fotoprincipal($chasis = null, $foto = null)
    {
        $sql = "update productos set pro_imagenapp = '" . $foto . "'  where pro_codori = '" . $chasis . "'";

        $connection = ConnectionManager::get('default');
        $connection->execute($sql);
        $connection->commit();
        $connection->disconnect();

        return $this->redirect(['action' => 'mostrar', trim($chasis)]); //
    }

    public function fotoprincipal2($chasis = null, $foto = null)
    {
        // luismoran: 06/05/2024

        $path1 = WWW_ROOT . 'img' . DS . 'chasis' . DS . $foto;
        $path2 = WWW_ROOT . 'img' . DS . 'chasisthumbs' . DS . 'thumb_' . $foto;
        $this->miniatura($path1, $path2, 80, 60);

        // luismoran

        $sql = "update productos set pro_imagenapp = '" . $foto . "'  where pro_codori = '" . $chasis . "'";

        $sql2 = "update inventarios set imagen = '" . $foto . "'  where upper(chasis) = '" . strtoupper($chasis) . "'";

        $connection = ConnectionManager::get('default');
        $connection->execute($sql);
        $connection->execute($sql2);
        $connection->commit();
        $connection->disconnect();

        echo "<script>history.go(-2)</script>";
        // return $this->redirect(['controller'=>'imagenapps',  'action' => 'add', trim($chasis)]); //
    }

    public function cuotafinal($id = null)
    {
        $stock = $this->Stocks->get($id, []);

        $this->set(compact('stock'));
        $this->set('_serialize', ['stock']);
    }

    public function cuotacontado($id = null)
    {
        $stock = $this->Stocks->get($id, []);

        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti) :
            $venta = $coti->doven;
            $compra = $coti->docom;
        endforeach;

        $Bonosdescuentos  =  TableRegistry::get('Bonosdescuentos');
        $bonosdescuento = $Bonosdescuentos->get(1);

        $this->set('bonosdescuento', $bonosdescuento);
        $this->set('cotiventa', $venta);
        $this->set('coticompra', $compra);
        $this->set(compact('stock'));
        $this->set('_serialize', ['stock']);
    }

    public function pedirbonos()
    {

        $this->request->allowMethod('ajax');

        $keyword = $this->request->query('keyword');

        $query = $this->Tags->find('all', [
            'conditions' => ['title iLIKE' => '%' . $keyword . '%'],
            'order' => ['Tags.id' => 'DESC'],
            'limit' => 10
        ]);
        echo 'este';
        $this->set('tags', $this->paginate($query));
        $this->set('_serialize', ['tags']);
    }

    public function agregarbono($chasis, $producto_id, $meses, $moneda, $total, $entrega, $saldo, $cuota, $montocuota, $refuerzo, $montorefuerzo, $empleado_id, $fecha, $hora, $tipopersona, $aleatorio, $totalbono, $fueradentro, $condicion, $efe, $vehi, $camba, $aumentar, $color, $llanta, $interior, $equipamiento, $camara, $buscahuella)
    {
        $query = TableRegistry::get('simulador_ventas')->query();

        $aleatorio = 0;

        $query->insert(['chasis', 'producto_id', 'meses', 'moneda', 'total', 'entrega', 'saldo', 'cuota', 'montocuota', 'refuerzo', 'montorefuerzo', 'empleado_id', 'fecha', 'hora', 'tipopersona', 'ci', 'telefono', 'aleatorio', 'veces', 'vecesgerente', 'vecessergio', 'estado', 'borrado', 'confirmado', 'totalbono', 'fueradentro', 'condicion', 'efectivo', 'vehiculo', 'cambalache', 'aumentar', 'color', 'llanta', 'interior', 'equipamiento', 'camara', 'buscahuella'])->values([

            'chasis' => $chasis,
            'producto_id' => $producto_id,
            'meses' => $meses,
            'moneda' => $moneda,
            'total' => $total,
            'entrega' => $entrega,
            'saldo' => $saldo,
            'cuota' => $cuota,
            'montocuota' => $montocuota,
            'refuerzo' => $refuerzo,
            'montorefuerzo' => $montorefuerzo,
            'empleado_id' => $empleado_id,
            'fecha' => str_replace("-", "/", $fecha),
            'hora' => str_replace("-", ":", $hora),
            'tipopersona' => $tipopersona,
            'ci' => '',
            'telefono' => '',
            'aleatorio' => $aleatorio,
            'veces' => 1,
            'vecesgerente' => 0,
            'vecessergio' => 0,
            'estado' => 0,
            'borrado' => 0,
            'confirmado' => 0,
            'totalbono' => $totalbono,
            'fueradentro' => $fueradentro,
            'condicion' => $condicion,
            'efectivo' => $efe,
            'vehiculo' => $vehi,
            'cambalache' => $camba,
            'aumentar' => $aumentar,
            'color' => $color,
            'llanta' => $llanta,
            'interior' => $interior,
            'equipamiento' => $equipamiento,
            'camara' => $camara,
            'buscahuella' => $buscahuella
        ])->execute();

        $simulador = TableRegistry::get('simulador_ventas');
        $querys = $simulador
            ->find()
            ->select(['id'])
            ->where([
                'chasis' => $chasis,
                'producto_id' => $producto_id,
                'meses' => $meses,
                'moneda' => $moneda,
                'total' => $total,
                'entrega' => $entrega,
                'saldo' => $saldo,
                'cuota' => $cuota,
                'montocuota' => $montocuota,
                'refuerzo' => $refuerzo,
                'montorefuerzo' => $montorefuerzo,
                'empleado_id' => $empleado_id,
                'fecha' =>  str_replace("-", "/", $fecha),
                'hora' => str_replace("-", ":", $hora),
                'tipopersona' => $tipopersona,
                'ci' => '',
                'telefono' => '',
                'aleatorio' => $aleatorio,
                'veces' => 1,
                'vecesgerente' => 0,
                'vecessergio' => 0,
                'estado' => 0,
                'borrado' => 0,
                'confirmado' => 0,
                'totalbono' => $totalbono,
                'fueradentro' => $fueradentro,
                'condicion' => $condicion,
                'efectivo' => $efe,
                'vehiculo' => $vehi,
                'cambalache' => $camba,
                'aumentar' => $aumentar,
                'color' => $color,
                'llanta' => $llanta,
                'interior' => $interior,
                'equipamiento' => $equipamiento,
                'camara' => $camara,
                'buscahuella' => $buscahuella
            ]);


        foreach ($querys as $bono) {
            //  return $this->redirect(['controller' => 'SimuladorVentas', 'action' => 'ver', $bono->id]);  
            return $this->redirect(['controller' => 'SimuladorVentas', 'action' => 'edit', $bono->id]);
        }
    }

    public function guardarventacredito($chasis, $producto_id, $meses, $moneda, $total, $entrega, $saldo, $cuota, $montocuota, $refuerzo, $montorefuerzo, $empleado_id, $fecha, $hora, $tipopersona, $aleatorio, $totalbono, $fueradentro, $condicion, $efe, $vehi, $camba, $aumentar, $color, $llanta, $interior, $equipamiento, $camara, $buscahuella)
    {
        $query = TableRegistry::get('simulador_ventas')->query();

        $query->insert(['chasis', 'producto_id', 'meses', 'moneda', 'total', 'entrega', 'saldo', 'cuota', 'montocuota', 'refuerzo', 'montorefuerzo', 'empleado_id', 'fecha', 'hora', 'tipopersona', 'ci', 'telefono', 'aleatorio', 'veces', 'vecesgerente', 'vecessergio', 'estado', 'borrado', 'confirmado', 'totalbono', 'fueradentro', 'condicion', 'efectivo', 'vehiculo', 'cambalache', 'aumentar', 'color', 'llanta', 'interior', 'equipamiento', 'camara', 'buscahuella'])->values([

            'chasis' => $chasis,
            'producto_id' => $producto_id,
            'meses' => $meses,
            'moneda' => $moneda,
            'total' => $total,
            'entrega' => $entrega,
            'saldo' => $saldo,
            'cuota' => $cuota,
            'montocuota' => $montocuota,
            'refuerzo' => $refuerzo,
            'montorefuerzo' => $montorefuerzo,
            'empleado_id' => $empleado_id,
            'fecha' => str_replace("-", "/", $fecha),
            'hora' => str_replace("-", ":", $hora),
            'tipopersona' => $tipopersona,
            'ci' => '',
            'telefono' => '',
            'aleatorio' => $aleatorio,
            'veces' => 0,
            'vecesgerente' => 0,
            'vecessergio' => 0,
            'estado' => 0,
            'borrado' => 0,
            'confirmado' => 0,
            'totalbono' => $totalbono,
            'fueradentro' => $fueradentro,
            'condicion' => $condicion,
            'efectivo' => $efe,
            'vehiculo' => $vehi,
            'cambalache' => $camba,
            'aumentar' => $aumentar,
            'color' => $color,
            'llanta' => $llanta,
            'interior' => $interior,
            'equipamiento' => $equipamiento,
            'camara' => $camara,
            'buscahuella' => $buscahuella

        ])->execute();

        $simulador = TableRegistry::get('simulador_ventas');
        $querys = $simulador
            ->find()
            ->select(['id'])
            ->where([
                'chasis' => $chasis,
                'producto_id' => $producto_id,
                'meses' => $meses,
                'moneda' => $moneda,
                'total' => $total,
                'entrega' => $entrega,
                'saldo' => $saldo,
                'cuota' => $cuota,
                'montocuota' => $montocuota,
                'refuerzo' => $refuerzo,
                'montorefuerzo' => $montorefuerzo,
                'empleado_id' => $empleado_id,
                'fecha' =>  str_replace("-", "/", $fecha),
                'hora' => str_replace("-", ":", $hora),
                'tipopersona' => $tipopersona,
                'ci' => '',
                'telefono' => '',
                'aleatorio' => $aleatorio,
                'veces' => 0,
                'vecesgerente' => 0,
                'vecessergio' => 0,
                'estado' => 0,
                'borrado' => 0,
                'confirmado' => 0,
                'totalbono' => $totalbono,
                'fueradentro' => $fueradentro,
                'condicion' => $condicion,
                'efectivo' => $efe,
                'vehiculo' => $vehi,
                'cambalache' => $camba,
                'aumentar' => $aumentar,
                'color' => $color,
                'llanta' => $llanta,
                'interior' => $interior,
                'equipamiento' => $equipamiento,
                'camara' => $camara,
                'buscahuella' => $buscahuella
            ]);

        foreach ($querys as $bono) {
            return $this->redirect(['controller' => 'SimuladorVentas', 'action' => 'edit', $bono->id]);
        }
    }

    public function agregarVentacontado($chasis, $producto_id, $meses, $moneda, $total, $entrega, $saldo, $cuota, $montocuota, $refuerzo, $montorefuerzo, $empleado_id, $fecha, $hora, $tipopersona, $aleatorio, $totalbono, $fueradentro, $condicion, $efe, $vehi, $camba, $aumentar, $color, $llanta, $interior, $equipamiento, $camara, $buscahuella)
    {
        $query = TableRegistry::get('simulador_ventas')->query();

        $query->insert(['chasis', 'producto_id', 'meses', 'moneda', 'total', 'entrega', 'saldo', 'cuota', 'montocuota', 'refuerzo', 'montorefuerzo', 'empleado_id', 'fecha', 'hora', 'tipopersona', 'ci', 'telefono', 'aleatorio', 'veces', 'vecesgerente', 'vecessergio', 'estado', 'borrado', 'confirmado', 'totalbono', 'fueradentro', 'condicion', 'efectivo', 'vehiculo', 'cambalache', 'aumentar', 'color', 'llanta', 'interior', 'equipamiento', 'camara', 'buscahuella'])->values([

            'chasis' => $chasis,
            'producto_id' => $producto_id,
            'meses' => $meses,
            'moneda' => $moneda,
            'total' => $total,
            'entrega' => $entrega,
            'saldo' => $saldo,
            'cuota' => $cuota,
            'montocuota' => $montocuota,
            'refuerzo' => $refuerzo,
            'montorefuerzo' => $montorefuerzo,
            'empleado_id' => $empleado_id,
            'fecha' => str_replace("-", "/", $fecha),
            'hora' => str_replace("-", ":", $hora),
            'tipopersona' => $tipopersona,
            'ci' => '',
            'telefono' => '',
            'aleatorio' => $aleatorio,
            'veces' => 0,
            'vecesgerente' => 0,
            'vecessergio' => 0,
            'estado' => 0,
            'borrado' => 0,
            'confirmado' => 0,
            'totalbono' => $totalbono,
            'fueradentro' => $fueradentro,
            'condicion' => $condicion,
            'efectivo' => $efe,
            'vehiculo' => $vehi,
            'cambalache' => $camba,
            'aumentar' => $aumentar,
            'color' => $color,
            'llanta' => $llanta,
            'interior' => $interior,
            'equipamiento' => $equipamiento,
            'camara' => $camara,
            'buscahuella' => $buscahuella

        ])->execute();

        $simulador = TableRegistry::get('simulador_ventas');
        $querys = $simulador
            ->find()
            ->select(['id'])
            ->where([
                'chasis' => $chasis,
                'producto_id' => $producto_id,
                'meses' => $meses,
                'moneda' => $moneda,
                'total' => $total,
                'entrega' => $entrega,
                'saldo' => $saldo,
                'cuota' => $cuota,
                'montocuota' => $montocuota,
                'refuerzo' => $refuerzo,
                'montorefuerzo' => $montorefuerzo,
                'empleado_id' => $empleado_id,
                'fecha' =>  str_replace("-", "/", $fecha),
                'hora' => str_replace("-", ":", $hora),
                'tipopersona' => $tipopersona,
                'ci' => '',
                'telefono' => '',
                'aleatorio' => $aleatorio,
                'veces' => 0,
                'vecesgerente' => 0,
                'vecessergio' => 0,
                'estado' => 0,
                'borrado' => 0,
                'confirmado' => 0,
                'totalbono' => $totalbono,
                'fueradentro' => $fueradentro,
                'condicion' => $condicion,
                'efectivo' => $efe,
                'vehiculo' => $vehi,
                'cambalache' => $camba,
                'aumentar' => $aumentar,
                'color' => $color,
                'llanta' => $llanta,
                'interior' => $interior,
                'equipamiento' => $equipamiento,
                'camara' => $camara,
                'buscahuella' => $buscahuella
            ]);

        foreach ($querys as $bono) {
            return $this->redirect(['controller' => 'SimuladorVentas', 'action' => 'edit', $bono->id]);
        }
    }

    public function pedirmasbono($idsimulador)
    {
        $simulador = TableRegistry::get('simulador_ventas');
        $simula = $simulador->get($idsimulador, [
            'contain' => ['Stocks']
        ]);

        $Bonosdescuentos = TableRegistry::get('bonosdescuentos');
        $bonosdescuento = $Bonosdescuentos->get(1);

        /// echo $bonosdescuento;
        $bono = 0;
        if ($simula->condicion == 1) {  // CONTADO
            if ($simula->stock->estado == 'USADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->usabonoacontado;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->usabonobcontado;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->usabonoccontado;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->usabonodcontado;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->usabonoecontado;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->usabonofcontado;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->usabonogcontado;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->usabonoacontadofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->usabonobcontadofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->usabonoccontadofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->usabonodcontadofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->usabonoecontadofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->usabonofcontadofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->usabonogcontadofuera;
                    }
                }
            } // FIN USADO

            if ($simula->stock->estado == 'RECIEN IMPORTADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->rimpbonoacontado;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->rimpbonobcontado;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->rimpbonoccontado;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->rimpbonodcontado;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->rimpbonoecontado;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->rimpbonofcontado;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->rimpbonogcontado;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->rimpbonoacontadofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->rimpbonobcontadofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->rimpbonoccontadofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->rimpbonodcontadofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->rimpbonoecontadofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->rimpbonofcontadofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->rimpbonogcontadofuera;
                    }
                }
            } // FIN RECIEN IMPORTADO
            if ($simula->stock->estado == 'RECUPERADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->recbonoacontado;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->recbonobcontado;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->recbonoccontado;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->recbonodcontado;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->recbonoecontado;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->recbonofcontado;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->recbonogcontado;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->recbonoacontadofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->recbonobcontadofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->recbonoccontadofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->recbonodcontadofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->recbonoecontadofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->recbonofcontadofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->recbonogcontadofuera;
                    }
                }
            } // FIN RECUPERADO

        } // FIN CONTADO

        if ($simula->condicion == 2) {  // credito
            if ($simula->stock->estado == 'USADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->usabonoacredito;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->usabonobcredito;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->usabonoccredito;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->usabonodcredito;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->usabonoecredito;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->usabonofcredito;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->usabonogcredito;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->usabonoacreditofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->usabonobcreditofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->usabonoccreditofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->usabonodcreditofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->usabonoecreditofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->usabonofcreditofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->usabonogcreditofuera;
                    }
                }
            } // FIN USADO

            if ($simula->stock->estado == 'RECIEN IMPORTADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->rimpbonoacredito;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->rimpbonobcredito;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->rimpbonoccredito;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->rimpbonodcredito;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->rimpbonoecredito;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->rimpbonofcredito;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->rimpbonogcredito;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->rimpbonoacreditofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->rimpbonobcreditofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->rimpbonoccreditofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->rimpbonodcreditofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->rimpbonoecreditofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->rimpbonofcreditofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->rimpbonogcreditofuera;
                    }
                }
            } // FIN RECIEN IMPORTADO
            if ($simula->stock->estado == 'RECUPERADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->recbonoacredito;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->recbonobcredito;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->recbonoccredito;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->recbonodcredito;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->recbonoecredito;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->recbonofcredito;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->recbonogcredito;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->recbonoacreditofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->recbonobcreditofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->recbonoccreditofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->recbonodcreditofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->recbonoecreditofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->recbonofcreditofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->recbonogcreditofuera;
                    }
                }
            } // FIN RECUPERADO

        } // FIN CREDITO

        $sql = "UPDATE simulador_ventas SET veces=veces+1, totalbono=totalbono + " . $bono . " WHERE id = " . $idsimulador;
        $connection = ConnectionManager::get('default');
        $connection->execute($sql);
        $connection->commit();
        $connection->disconnect();
        return $this->redirect(['controller' => 'SimuladorVentas', 'action' => 'movil']); //
    }

    public function pedirmas2bono($idsimulador = null, $empresa = null)
    {
        $simulador = TableRegistry::get('simulador_ventas');
        $simula = $simulador->get($idsimulador, [
            'contain' => ['Stocks']
        ]);
        $Bonosdescuentos = TableRegistry::get('bonosdescuentos');
        $bonosdescuento = $Bonosdescuentos->get(1);

        $bono = 0;
        if ($simula->condicion == 1) {  // CONTADO
            if ($simula->stock->estado == 'USADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->usabonoacontado;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->usabonobcontado;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->usabonoccontado;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->usabonodcontado;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->usabonoecontado;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->usabonofcontado;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->usabonogcontado;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->usabonoacontadofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->usabonobcontadofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->usabonoccontadofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->usabonodcontadofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->usabonoecontadofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->usabonofcontadofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->usabonogcontadofuera;
                    }
                }
            } /// fin usado

            if ($simula->stock->estado == 'RECIEN IMPORTADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->rimpbonoacontado;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->rimpbonobcontado;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->rimpbonoccontado;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->rimpbonodcontado;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->rimpbonoecontado;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->rimpbonofcontado;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->rimpbonogcontado;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->rimpbonoacontadofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->rimpbonobcontadofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->rimpbonoccontadofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->rimpbonodcontadofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->rimpbonoecontadofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->rimpbonofcontadofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->rimpbonogcontadofuera;
                    }
                }
            } // FIN RECIEN IMPORTADO
            if ($simula->stock->estado == 'RECUPERADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->recbonoacontado;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->recbonobcontado;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->recbonoccontado;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->recbonodcontado;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->recbonoecontado;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->recbonofcontado;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->recbonogcontado;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->recbonoacontadofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->recbonobcontadofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->recbonoccontadofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->recbonodcontadofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->recbonoecontadofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->recbonofcontadofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->recbonogcontadofuera;
                    }
                }
            } // FIN RECUPERADO
        } /// FIN CONTADO

        if ($simula->condicion == 2) {  // credito
            if ($simula->stock->estado == 'USADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->usabonoacredito;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->usabonobcredito;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->usabonoccredito;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->usabonodcredito;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->usabonoecredito;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->usabonofcredito;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->usabonogcredito;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->usabonoacreditofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->usabonobcreditofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->usabonoccreditofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->usabonodcreditofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->usabonoecreditofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->usabonofcreditofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->usabonogcreditofuera;
                    }
                }
            } // FIN USADO

            if ($simula->stock->estado == 'RECIEN IMPORTADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->rimpbonoacredito;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->rimpbonobcredito;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->rimpbonoccredito;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->rimpbonodcredito;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->rimpbonoecredito;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->rimpbonofcredito;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->rimpbonogcredito;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->rimpbonoacreditofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->rimpbonobcreditofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->rimpbonoccreditofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->rimpbonodcreditofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->rimpbonoecreditofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->rimpbonofcreditofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->rimpbonogcreditofuera;
                    }
                }
            } // FIN RECIEN IMPORTADO
            if ($simula->stock->estado == 'RECUPERADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->recbonoacredito;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->recbonobcredito;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->recbonoccredito;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->recbonodcredito;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->recbonoecredito;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->recbonofcredito;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->recbonogcredito;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->recbonoacreditofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->recbonobcreditofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->recbonoccreditofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->recbonodcreditofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->recbonoecreditofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->recbonofcreditofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->recbonogcreditofuera;
                    }
                }
            } // FIN RECUPERADO
        } // FIN CREDITO


        $sql = "UPDATE simulador_ventas SET veces = veces + 1, totalbono = totalbono + " . $bono . " WHERE id = " . $idsimulador;
        if ($this->Auth->User('id') == 1) {
            debug($simula . ' --- ' . $sql);
            exit();
        }
        $connection = ConnectionManager::get('default');
        $connection->execute($sql);
        $connection->commit();
        $connection->disconnect();

        return $this->redirect(['controller' => 'SimuladorVentas', 'action' => 'listadogerente/' . $empresa]);
    }

    public function cuotanew($id = null)
    {
        $stock = $this->Stocks->get($id, []);

        $cotizacions = TableRegistry::get('cotizacions');
        $querycoti = $cotizacions->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($querycoti as $coti) :
            $venta = $coti->doven;
            $compra = $coti->docom;
        endforeach;

        $Bonosdescuentos  =  TableRegistry::get('Bonosdescuentos');
        $bonosdescuento = $Bonosdescuentos->get(1);

        $AdministradorPrecio  =  TableRegistry::get('administrador_precios');
        $administradorprecio = $AdministradorPrecio->get(1);

        $this->set('precios', $administradorprecio);
        $this->set('bonosdescuento', $bonosdescuento);
        $this->set('cotiventa', $venta);
        $this->set('coticompra', $compra);
        $this->set(compact('stock'));
        $this->set('_serialize', ['stock']);
    }

    public function pedirmasbonobuscador($idsimulador = null, $empresa = null)
    {
        $simulador = TableRegistry::get('simulador_ventas');
        $simula = $simulador->get($idsimulador, [
            'contain' => ['Stocks']
        ]);

        $Bonosdescuentos = TableRegistry::get('bonosdescuentos');
        $bonosdescuento = $Bonosdescuentos->get(1);
        $bono = 0;
        if ($simula->condicion == 1) {  // CONTADO
            if ($simula->stock->estado == 'USADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->usabonoacontado;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->usabonobcontado;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->usabonoccontado;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->usabonodcontado;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->usabonoecontado;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->usabonofcontado;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->usabonogcontado;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->usabonoacontadofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->usabonobcontadofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->usabonoccontadofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->usabonodcontadofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->usabonoecontadofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->usabonofcontadofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->usabonogcontadofuera;
                    }
                }
            } /// fin usado

            if ($simula->stock->estado == 'RECIEN IMPORTADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->rimpbonoacontado;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->rimpbonobcontado;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->rimpbonoccontado;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->rimpbonodcontado;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->rimpbonoecontado;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->rimpbonofcontado;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->rimpbonogcontado;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->rimpbonoacontadofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->rimpbonobcontadofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->rimpbonoccontadofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->rimpbonodcontadofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->rimpbonoecontadofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->rimpbonofcontadofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->rimpbonogcontadofuera;
                    }
                }
            } // FIN RECIEN IMPORTADO
            if ($simula->stock->estado == 'RECUPERADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->recbonoacontado;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->recbonobcontado;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->recbonoccontado;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->recbonodcontado;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->recbonoecontado;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->recbonofcontado;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->recbonogcontado;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->recbonoacontadofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->recbonobcontadofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->recbonoccontadofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->recbonodcontadofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->recbonoecontadofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->recbonofcontadofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->recbonogcontadofuera;
                    }
                }
            } // FIN RECUPERADO
        } /// FIN CONTADO

        if ($simula->condicion == 2) {  // credito
            if ($simula->stock->estado == 'USADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->usabonoacredito;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->usabonobcredito;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->usabonoccredito;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->usabonodcredito;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->usabonoecredito;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->usabonofcredito;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->usabonogcredito;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->usabonoacreditofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->usabonobcreditofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->usabonoccreditofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->usabonodcreditofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->usabonoecreditofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->usabonofcreditofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->usabonogcreditofuera;
                    }
                }
            } // FIN USADO

            if ($simula->stock->estado == 'RECIEN IMPORTADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->rimpbonoacredito;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->rimpbonobcredito;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->rimpbonoccredito;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->rimpbonodcredito;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->rimpbonoecredito;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->rimpbonofcredito;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->rimpbonogcredito;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->rimpbonoacreditofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->rimpbonobcreditofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->rimpbonoccreditofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->rimpbonodcreditofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->rimpbonoecreditofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->rimpbonofcreditofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->rimpbonogcreditofuera;
                    }
                }
            } // FIN RECIEN IMPORTADO
            if ($simula->stock->estado == 'RECUPERADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->recbonoacredito;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->recbonobcredito;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->recbonoccredito;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->recbonodcredito;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->recbonoecredito;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->recbonofcredito;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->recbonogcredito;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->recbonoacreditofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->recbonobcreditofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->recbonoccreditofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->recbonodcreditofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->recbonoecreditofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->recbonofcreditofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->recbonogcreditofuera;
                    }
                }
            } // FIN RECUPERADO
        } // FIN CREDITO

        $sql = "UPDATE simulador_ventas SET veces = veces + 1, totalbono = totalbono + " . $bono . " WHERE id = " . $idsimulador;

        $connection = ConnectionManager::get('default');
        $connection->execute($sql);
        $connection->commit();
        $connection->disconnect();

        // return $this->redirect(['controller'=>'SimuladorVentas', 'action' => 'listadogerente/'. $empresa]); //
        echo "<script>history.go(-1)</script>";
    }

    public function cuotascrip($id = null) {}

    public function cuotacredito($id = null)
    {
        if ($this->request->is(['patch', 'post', 'put'])) {
            $SimuladorVentas = TableRegistry::get('simuladorVentas');
            $simuladorVenta = $SimuladorVentas->newEntity();
            $simuladorVenta = $SimuladorVentas->patchEntity($simuladorVenta, $this->request->getData());
            $SimuladorVentas->save($simuladorVenta);

            $stock = $this->Stocks->get($id, []);
            $Bonosdescuentos  =  TableRegistry::get('Bonosdescuentos');
            $bonosdescuento = $Bonosdescuentos->get(1);

            $cotizacions = TableRegistry::get('cotizacions');
            $querycoti = $cotizacions->find('all');
            $cotiventa = 0;
            $cotiventa = 0;
            foreach ($querycoti as $coti) :
                $cotiventa = $coti->doven;
                $coticompra = $coti->docom;
            endforeach;
            $AdministradorPrecio  =  TableRegistry::get('administrador_precios');
            $precios = $AdministradorPrecio->get(1);
            $ver = 1;


            $Simulador = TableRegistry::get('simuladorVentas');
            $simulador = $Simulador->get($simuladorVenta->id);
            $this->set('simuladorVenta', $simulador);

            $this->set('ver', $ver);
            $this->set('precios', $precios);
            $this->set('bonosdescuento', $bonosdescuento);
            $this->set('cotiventa', $cotiventa);
            $this->set('coticompra', $coticompra);
            echo "<script>history.go(-1)</script>";
        } else {
            $ver = 0;
            if (isset($this->request->query['submit'])) {

                $stock = $this->Stocks->get($id, []);
                $Bonosdescuentos  =  TableRegistry::get('Bonosdescuentos');
                $bonosdescuento = $Bonosdescuentos->get(1);

                $cotizacions = TableRegistry::get('cotizacions');
                $querycoti = $cotizacions->find('all');
                $cotiventa = 0;
                $cotiventa = 0;
                foreach ($querycoti as $coti) :
                    $cotiventa = $coti->doven;
                    $coticompra = $coti->docom;
                endforeach;

                $AdministradorPrecio  =  TableRegistry::get('administrador_precios');
                $precios = $AdministradorPrecio->get(1);

                $moneda = $this->request->query['comboMoneda'];
                $entrega = $this->request->query['txtEntrega'];
                $entregave = $this->request->query['txtEntregave'];
                $cambalache = $this->request->query['txtCambalache'];
                $cantidadrefuerzo = $this->request->query['txtCantidadRefuerzo'];
                $refuerzo = $this->request->query['txtRefuerzo'];
                $bono = $this->request->query['txtBono'];

                //COMBOS
                $color = $this->request->query['cboxColor'];
                $llanta = $this->request->query['cboxLlanta'];
                $interior = $this->request->query['cboxInterior'];
                $equipamiento = $this->request->query['cboxEquipamiento'];
                $camara = $this->request->query['cboxCamara'];
                $buscahuella = $this->request->query['cboxBuscaHuella'];

                //PROPUESTA

                $ci = $this->request->query['txtCedula'];
                $telefono = $this->request->query['txtTelefono'];
                $combotipo = $this->request->query['comboTipo'];

                //$prop_entrega = $this->request->query['txtProp_entrega'];
                //$prop_cantidadcuota = $this->request->query['txtProp_cantidadcuota'];
                //$prop_montocuota = $this->request->query['txtProp_montocuota'];
                //$prop_cantidadref = $this->request->query['txtProp_cantidadref'];
                //$prop_montoref = $this->request->query['txtProp_montoref'];
                // $prop_total = $this->request->query['txtProp_total'];

                // if($prop_entrega == null){ $prop_entrega = 0; }
                //if($prop_cantidadcuota == null){ $prop_cantidadcuota = 0; }
                //if($prop_montocuota == null){ $prop_montocuota = 0; }
                // if($prop_cantidadref == null){ $prop_cantidadref = 0; }
                //if($prop_montoref == null){ $prop_montoref = 0; }
                //if($prop_total == null){ $prop_total = 0; }

                //AUMENTAR
                $aumentar = 0;
                if ($color == 1) {
                    $aumentar = $aumentar + 300;
                } else {
                    $color = 0;
                }
                if ($llanta == 1) {
                    $aumentar = $aumentar + 500;
                } else {
                    $llanta = 0;
                }
                if ($interior == 1) {
                    $aumentar = $aumentar + 100;
                } else {
                    $interior = 0;
                }
                if ($equipamiento == 1) {
                    $aumentar = $aumentar + 100;
                } else {
                    $equipamiento = 0;
                }
                if ($camara == 1) {
                    $aumentar = $aumentar + 100;
                } else {
                    $camara = 0;
                }
                if ($buscahuella == 1) {
                    $aumentar = $aumentar + 100;
                } else {
                    $buscahuella = 0;
                }

                // SE INICIALIZA CASO NULL
                if ($entrega == null) {
                    $entrega = 0;
                }
                if ($entregave == null) {
                    $entregave = 0;
                }
                if ($cambalache == null) {
                    $cambalache = 0;
                }
                if ($cantidadrefuerzo == null) {
                    $cantidadrefuerzo = 0;
                }
                if ($refuerzo == null) {
                    $refuerzo = 0;
                }
                if ($bono == null) {
                    $bono = 0;
                }


                $totalentrega = $entrega + $cambalache + $entregave;
                $entregareal = $entrega + $entregave;

                $plazo = $this->request->query['comboPlazo']; //$this->request->query

                $cuota = 0;
                $montototal = 0;
                if ($plazo < 12) { // CONTADO 3 MESES
                    if ($plazo < 3) {
                        $cuota = $plazo;
                        $montototal = $stock->contado3meses - (100 * (3 - $cuota));
                    }
                    if ($plazo == 3) {
                        $cuota = $plazo;
                        $montototal = $stock->contado3meses;
                    }
                    if ($plazo > 3) {
                        $cuota = $plazo;
                        $montototal = $stock->contado3meses + (100 * ($cuota - 3));
                    }
                }

                if ($plazo >= 12) {
                    if ($plazo < 36) {
                        $cuota = $plazo;
                        $montototal = $stock->meses36 - (100 * (36 - $cuota));
                        if ($current_user['id'] == 1) {
                            // echo  (100 * (36 - $cuota));
                        }
                    }
                    if ($plazo == 36) {
                        $cuota = $plazo;
                        $montototal = $stock->meses36;
                    }
                }

                if ($cuota > 0) {
                    if ($totalentrega > 0) {
                        if ($moneda == 1) {  // DOLARES
                            if ($totalentrega > 99999) {
                                $this->Flash->error("VERIFIQUE LA MONEDA SI ESTA CORRECTO!");
                            } else {
                                $resta = $stock->entregaminima - $entregareal;

                                if ($resta <= $precios->menosentrega) {
                                    $aumentarresta = 0;
                                    $fueradentro = 0;
                                    if ($resta > 0) {
                                        $aumentarresta = $resta * ($precios->tasainteres / 100);
                                        $fueradentro = 1;
                                    }
                                    $total = $montototal + $aumentar + $aumentarresta + $cambalache;
                                    $saldo = $total - $totalentrega;
                                    $cantidadcuota = $cuota - $cantidadrefuerzo;
                                    $montocuota = ($saldo - ($cantidadrefuerzo * $refuerzo)) / $cantidadcuota;


                                    if ($cantidadrefuerzo > 0) {
                                        if ($refuerzo > 0) {
                                            if ($cuota > $cantidadrefuerzo) {
                                                $condicion = 2;
                                                $bono_a = 0;
                                                $bono_b = 0;
                                                $bono_c = 0;
                                                if ($fueradentro == 0) {
                                                    if ($stock->estado == 'USADO') {
                                                        $bono_a = $bonosdescuento->usabonoacredito;
                                                        $bono_b = $bonosdescuento->usabonobcredito;
                                                        $bono_c = $bonosdescuento->usabonoccredito;
                                                    }
                                                    if ($stock->estado == 'RECIEN IMPORTADO') {
                                                        $bono_a = $bonosdescuento->rimpbonoacredito;
                                                        $bono_b = $bonosdescuento->rimpbonobcredito;
                                                        $bono_c = $bonosdescuento->rimpbonoccredito;
                                                    }
                                                    if ($stock->estado == 'RECUPERADO') {
                                                        $bono_a = $bonosdescuento->recbonoacredito;
                                                        $bono_b = $bonosdescuento->recbonobcredito;
                                                        $bono_c = $bonosdescuento->recbonoccredito;
                                                    }
                                                } else {
                                                    if ($stock->estado == 'USADO') {
                                                        $bono_a = $bonosdescuento->usabonoacreditofuera;
                                                        $bono_b = $bonosdescuento->usabonobcreditofuera;
                                                        $bono_c = $bonosdescuento->usabonoccreditofuera;
                                                    }
                                                    if ($stock->estado == 'RECIEN IMPORTADO') {
                                                        $bono_a = $bonosdescuento->rimpbonoacreditofuera;
                                                        $bono_b = $bonosdescuento->rimpbonobcreditofuera;
                                                        $bono_c = $bonosdescuento->rimpbonoccreditofuera;
                                                    }
                                                    if ($stock->estado == 'RECUPERADO') {
                                                        $bono_a = $bonosdescuento->recbonoacreditofuera;
                                                        $bono_b = $bonosdescuento->recbonobcreditofuera;
                                                        $bono_c = $bonosdescuento->recbonoccreditofuera;
                                                    }
                                                }

                                                $cantidaddebonoliberado = 0;
                                                $bonoliberado = 0;
                                                if ($bono > 0) { //cargo bono
                                                    if ($bono >= $bono_a) {
                                                        if ($bono == $bono_a) {
                                                            $bonoliberado = $bono_a;
                                                            $cantidaddebonoliberado = 1;
                                                        } else {
                                                            if ($bono >= ($bono_a + $bono_b)) {
                                                                if ($bono == ($bono_a + $bono_b)) {
                                                                    $bonoliberado = $bono;
                                                                    $cantidaddebonoliberado = 2;
                                                                } else {
                                                                    if ($bono >= ($bono_a + $bono_b + $bono_c)) {
                                                                        if ($bono == ($bono_a + $bono_b + $bono_c)) {
                                                                            $bonoliberado = $bono;
                                                                            $cantidaddebonoliberado = 3;
                                                                        } else {
                                                                            $bonoliberado = $bono_a + $bono_b + $bono_c;
                                                                            $cantidaddebonoliberado = 3;
                                                                        }
                                                                    } else {
                                                                        $bonoliberado = $bono;
                                                                        $cantidaddebonoliberado = 3;
                                                                    }
                                                                }
                                                            } else {
                                                                $bonoliberado = $bono;
                                                                $cantidaddebonoliberado = 2;
                                                            }
                                                        }
                                                    } else {
                                                        $bonoliberado = $bono;
                                                        $cantidaddebonoliberado = 1;
                                                    }
                                                }

                                                $this->agregarbononuevo(trim($stock->chasis), $stock->id, $plazo, $moneda, $total, $totalentrega, $saldo, $cantidadcuota, $montocuota, $cantidadrefuerzo, $refuerzo, $this->Auth->User('empleado'), date('d-m-Y'), date('H-i-s'), 0, 0, $bonoliberado, $fueradentro, $condicion, $entrega, $entregave, $cambalache, $aumentar, $color, $llanta, $interior, $equipamiento, $camara, $buscahuella, $bono,  $cantidaddebonoliberado, $ci, $telefono);

                                                $total = $total - $bonoliberado;
                                                $saldo = $total - $totalentrega;
                                                $cantidadcuota = $cuota - $cantidadrefuerzo;
                                                $montocuota = ($saldo - ($cantidadrefuerzo * $refuerzo)) / $cantidadcuota;
                                                $ver = 1;

                                                $info = array('Dolares', $total, $totalentrega, $saldo, $cantidadcuota, $montocuota, $cantidadrefuerzo, $refuerzo,  $this->property, $bono, $bonoliberado);
                                                $this->set('info', $info);


                                                $Simulador = TableRegistry::get('simuladorVentas');
                                                $simulador = $Simulador->get($this->property);
                                                $this->set('simuladorVenta', $simulador);
                                            } else {
                                                $this->Flash->error("LA CANTIDAD DEL REFUERZO NO PUEDE SER MAYOR A LAS CUOTAS");
                                            }
                                        } else {
                                            $this->Flash->error("EL MONTO DEL REFUERZO DEBE SER MAYOR A 0 DOLAR");
                                        } // FIN MONTO REFUERZO
                                    } else {
                                        $cantidadcuota = $cuota;
                                        $montocuota = $saldo / $cantidadcuota;
                                        $condicion = 2;

                                        $bono_a = 0;
                                        $bono_b = 0;
                                        $bono_c = 0;
                                        if ($fueradentro == 0) {
                                            if ($stock->estado == 'USADO') {
                                                $bono_a = $bonosdescuento->usabonoacredito;
                                                $bono_b = $bonosdescuento->usabonobcredito;
                                                $bono_c = $bonosdescuento->usabonoccredito;
                                            }
                                            if ($stock->estado == 'RECIEN IMPORTADO') {
                                                $bono_a = $bonosdescuento->rimpbonoacredito;
                                                $bono_b = $bonosdescuento->rimpbonobcredito;
                                                $bono_c = $bonosdescuento->rimpbonoccredito;
                                            }
                                            if ($stock->estado == 'RECUPERADO') {
                                                $bono_a = $bonosdescuento->recbonoacredito;
                                                $bono_b = $bonosdescuento->recbonobcredito;
                                                $bono_c = $bonosdescuento->recbonoccredito;
                                            }
                                        } else {
                                            if ($stock->estado == 'USADO') {
                                                $bono_a = $bonosdescuento->usabonoacreditofuera;
                                                $bono_b = $bonosdescuento->usabonobcreditofuera;
                                                $bono_c = $bonosdescuento->usabonoccreditofuera;
                                            }
                                            if ($stock->estado == 'RECIEN IMPORTADO') {
                                                $bono_a = $bonosdescuento->rimpbonoacreditofuera;
                                                $bono_b = $bonosdescuento->rimpbonobcreditofuera;
                                                $bono_c = $bonosdescuento->rimpbonoccreditofuera;
                                            }
                                            if ($stock->estado == 'RECUPERADO') {
                                                $bono_a = $bonosdescuento->recbonoacreditofuera;
                                                $bono_b = $bonosdescuento->recbonobcreditofuera;
                                                $bono_c = $bonosdescuento->recbonoccreditofuera;
                                            }
                                        }

                                        $cantidaddebonoliberado = 0;
                                        $bonoliberado = 0;
                                        if ($bono > 0) { //cargo bono
                                            if ($bono >= $bono_a) {
                                                if ($bono == $bono_a) {
                                                    $bonoliberado = $bono_a;
                                                    $cantidaddebonoliberado = 1;
                                                } else {
                                                    if ($bono >= ($bono_a + $bono_b)) {
                                                        if ($bono == ($bono_a + $bono_b)) {
                                                            $bonoliberado = $bono;
                                                            $cantidaddebonoliberado = 2;
                                                        } else {
                                                            if ($bono >= ($bono_a + $bono_b + $bono_c)) {
                                                                if ($bono == ($bono_a + $bono_b + $bono_c)) {
                                                                    $bonoliberado = $bono;
                                                                    $cantidaddebonoliberado = 3;
                                                                } else {
                                                                    $bonoliberado = $bono_a + $bono_b + $bono_c;
                                                                    $cantidaddebonoliberado = 3;
                                                                }
                                                            } else {
                                                                $bonoliberado = $bono;
                                                                $cantidaddebonoliberado = 3;
                                                            }
                                                        }
                                                    } else {
                                                        $bonoliberado = $bono;
                                                        $cantidaddebonoliberado = 2;
                                                    }
                                                }
                                            } else {
                                                $bonoliberado = $bono;
                                                $cantidaddebonoliberado = 1;
                                            }
                                        }

                                        $this->agregarbononuevo(trim($stock->chasis), $stock->id, $plazo, $moneda, $total, $totalentrega, $saldo, $cantidadcuota, $montocuota, $cantidadrefuerzo, $refuerzo, $this->Auth->User('empleado'), date('d-m-Y'), date('H-i-s'), 0, 0, $bonoliberado, $fueradentro, $condicion, $entrega, $entregave, $cambalache, $aumentar, $color, $llanta, $interior, $equipamiento, $camara, $buscahuella, $bono,  $cantidaddebonoliberado, $ci, $telefono);

                                        $total = $total - $bonoliberado;
                                        $saldo = $total - $totalentrega;
                                        $cantidadcuota = $cuota - $cantidadrefuerzo;
                                        $montocuota = ($saldo - ($cantidadrefuerzo * $refuerzo)) / $cantidadcuota;
                                        $ver = 1;

                                        $info = array('Dolares', $total, $totalentrega, $saldo, $cantidadcuota, $montocuota, $cantidadrefuerzo, $refuerzo,  $this->property, $bono, $bonoliberado);
                                        $this->set('info', $info);


                                        $Simulador = TableRegistry::get('simuladorVentas');
                                        $simulador = $Simulador->get($this->property);
                                        $this->set('simuladorVenta', $simulador);
                                    } // FIN CANT REFUERZO
                                } else {
                                    $this->Flash->error("LAS ENTREGA NO PUEDEN SER MENOR A: " . ($stock->entregaminima - $precios->menosentrega) . " DOLARES ");
                                } // RESTA ENTREGA
                            }
                        } // FIN DOLARES

                        if ($moneda == 2) {  // GUARANIES
                            $resta = ($stock->entregaminima * $cotiventa) - $entregareal;
                            if ($resta <= ($precios->menosentrega * $cotiventa)) {
                                $aumentarresta = 0;
                                $fueradentro = 0;
                                if ($resta > 0) {
                                    $aumentarresta = $resta * ($precios->tasainteres / 100);
                                    $fueradentro = 1;
                                }

                                $total = $montototal + $aumentar + (($aumentarresta + $cambalache) / $cotiventa);
                                $saldo = $total - ($totalentrega / $cotiventa);

                                echo '$total: ' . $total . ' $saldo ' . $saldo . ' - $totalentrega: ' . $totalentrega  . ' - cotiventa: ' . $cotiventa;

                                $saldoguarani = ($saldo * ($cotiventa + 50));
                                $totalguaranies = $saldoguarani + $totalentrega;



                                if ($cantidadrefuerzo > 0) {
                                    if ($refuerzo > 0) {
                                        if ($cuota > $cantidadrefuerzo) {

                                            $cantidadcuota = $cuota - $cantidadrefuerzo;
                                            $montocuota = ($saldoguarani - ($cantidadrefuerzo * $refuerzo)) / $cantidadcuota;
                                            $ver = 1;

                                            $condicion = 2;

                                            $bono_a = 0;
                                            $bono_b = 0;
                                            $bono_c = 0;
                                            if ($fueradentro == 0) {
                                                if ($stock->estado == 'USADO') {
                                                    $bono_a = $bonosdescuento->usabonoacredito * $cotiventa;
                                                    $bono_b = $bonosdescuento->usabonobcredito * $cotiventa;
                                                    $bono_c = $bonosdescuento->usabonoccredito * $cotiventa;
                                                }
                                                if ($stock->estado == 'RECIEN IMPORTADO') {
                                                    $bono_a = $bonosdescuento->rimpbonoacredito * $cotiventa;
                                                    $bono_b = $bonosdescuento->rimpbonobcredito * $cotiventa;
                                                    $bono_c = $bonosdescuento->rimpbonoccredito * $cotiventa;
                                                }
                                                if ($stock->estado == 'RECUPERADO') {
                                                    $bono_a = $bonosdescuento->recbonoacredito * $cotiventa;
                                                    $bono_b = $bonosdescuento->recbonobcredito * $cotiventa;
                                                    $bono_c = $bonosdescuento->recbonoccredito * $cotiventa;
                                                }
                                            } else {
                                                if ($stock->estado == 'USADO') {
                                                    $bono_a = $bonosdescuento->usabonoacreditofuera * $cotiventa;
                                                    $bono_b = $bonosdescuento->usabonobcreditofuera * $cotiventa;
                                                    $bono_c = $bonosdescuento->usabonoccreditofuera * $cotiventa;
                                                }
                                                if ($stock->estado == 'RECIEN IMPORTADO') {
                                                    $bono_a = $bonosdescuento->rimpbonoacreditofuera * $cotiventa;
                                                    $bono_b = $bonosdescuento->rimpbonobcreditofuera * $cotiventa;
                                                    $bono_c = $bonosdescuento->rimpbonoccreditofuera * $cotiventa;
                                                }
                                                if ($stock->estado == 'RECUPERADO') {
                                                    $bono_a = $bonosdescuento->recbonoacreditofuera * $cotiventa;
                                                    $bono_b = $bonosdescuento->recbonobcreditofuera * $cotiventa;
                                                    $bono_c = $bonosdescuento->recbonoccreditofuera * $cotiventa;
                                                }
                                            }



                                            $total = $montototal + $aumentar + (($aumentarresta + $cambalache) / $cotiventa);


                                            $cantidaddebonoliberado = 0;
                                            $bonoliberado = 0;
                                            if ($bono > 0) { //cargo bono
                                                if ($bono >= $bono_a) {
                                                    if ($bono == $bono_a) {
                                                        $bonoliberado = $bono_a;
                                                        $cantidaddebonoliberado = 1;
                                                    } else {
                                                        if ($bono >= ($bono_a + $bono_b)) {
                                                            if ($bono == ($bono_a + $bono_b)) {
                                                                $bonoliberado = $bono;
                                                                $cantidaddebonoliberado = 2;
                                                            } else {
                                                                if ($bono >= ($bono_a + $bono_b + $bono_c)) {
                                                                    if ($bono == ($bono_a + $bono_b + $bono_c)) {
                                                                        $bonoliberado = $bono;
                                                                        $cantidaddebonoliberado = 3;
                                                                    } else {
                                                                        $bonoliberado = $bono_a + $bono_b + $bono_c;
                                                                        $cantidaddebonoliberado = 3;
                                                                    }
                                                                } else {
                                                                    $bonoliberado = $bono;
                                                                    $cantidaddebonoliberado = 3;
                                                                }
                                                            }
                                                        } else {
                                                            $bonoliberado = $bono;
                                                            $cantidaddebonoliberado = 2;
                                                        }
                                                    }
                                                } else {
                                                    $bonoliberado = $bono;
                                                    $cantidaddebonoliberado = 1;
                                                }
                                            }

                                            $this->agregarbononuevo(trim($stock->chasis), $stock->id, $plazo, $moneda, $totalguaranies, $totalentrega, $saldoguarani, $cantidadcuota, $montocuota, $cantidadrefuerzo, $refuerzo, $this->Auth->User('empleado'), date('d-m-Y'), date('H-i-s'), 0, 0, $bonoliberado, $fueradentro, $condicion, $entrega, $entregave, $cambalache, $aumentar, $color, $llanta, $interior, $equipamiento, $camara, $buscahuella, $bono,  $cantidaddebonoliberado, $ci, $telefono);



                                            $total = $total - $bonoliberado;
                                            $saldo = $total - $totalentrega;

                                            $saldoguarani = ($saldo * ($cotiventa + 50));
                                            $totalguaranies = $saldoguarani + $totalentrega;

                                            $cantidadcuota = $cuota - $cantidadrefuerzo;
                                            $montocuota = ($saldoguarani - ($cantidadrefuerzo * $refuerzo)) / $cantidadcuota;

                                            $ver = 1;

                                            $info = array('Guaranies', $totalguaranies, $totalentrega, $saldoguarani, $cantidadcuota, $montocuota, $cantidadrefuerzo, $refuerzo,  $this->property, $bono, $bonoliberado);
                                            $this->set('info', $info);

                                            $Simulador = TableRegistry::get('simuladorVentas');
                                            $simulador = $Simulador->get($this->property);
                                            $this->set('simuladorVenta', $simulador);

                                            //echo $this->Html->link('PEDIR BONO', [ 'action' => 'agregarbono',  trim($stock->chasis), $stock->id, $plazo, $moneda, $totalguaranies, $totalentrega, $saldoguarani, $cantidadcuota, $montocuota, $cantidadrefuerzo, $refuerzo, $current_user['empleado'] , date('d-m-Y'), date('H-i-s'), 0 , 0, $bono, $fueradentro, $condicion, $entrega , $entregave, $cambalache, $aumentar, $color, $llanta, $interior, $equipamiento, $camara, $buscahuella ], ['class' => 'btn btn-primary btn-lg btn-block'], ['method' => 'POST']) ;
                                            //echo $this->Html->link('GUARDAR VENTA', [ 'action' => 'guardarventacredito', trim($stock->chasis), $stock->id, $plazo, $moneda, $totalguaranies, $totalentrega, $saldoguarani, $cantidadcuota, $montocuota, $cantidadrefuerzo, $refuerzo, $current_user['empleado'] , date('d-m-Y'), date('H-i-s'), 0 , 0, 0, $fueradentro, $condicion, $entrega , $entregave, $cambalache, $aumentar, $color, $llanta, $interior, $equipamiento, $camara, $buscahuella ], ['class' => 'btn btn-success btn-lg btn-block'], ['method' => 'POST']) ;

                                        } else {
                                            $this->Flash->error("LA CANTIDAD DEL REFUERZO NO PUEDE SER MAYOR A LAS CUOTAS");
                                        }
                                    } else {
                                        $this->Flash->error("EL MONTO DEL REFUERZO DEBE SER MAYOR A 0 DOLAR");
                                    } // FIN MONTO REFUERZO
                                } else {

                                    $cantidadcuota = $cuota - $cantidadrefuerzo;
                                    $montocuota = ($saldoguarani - ($cantidadrefuerzo * $refuerzo)) / $cantidadcuota;
                                    $ver = 1;

                                    $condicion = 2;

                                    $bono_a = 0;
                                    $bono_b = 0;
                                    $bono_c = 0;
                                    if ($fueradentro == 0) {
                                        if ($stock->estado == 'USADO') {
                                            $bono_a = $bonosdescuento->usabonoacredito * $cotiventa;
                                            $bono_b = $bonosdescuento->usabonobcredito * $cotiventa;
                                            $bono_c = $bonosdescuento->usabonoccredito * $cotiventa;
                                        }
                                        if ($stock->estado == 'RECIEN IMPORTADO') {
                                            $bono_a = $bonosdescuento->rimpbonoacredito * $cotiventa;
                                            $bono_b = $bonosdescuento->rimpbonobcredito * $cotiventa;
                                            $bono_c = $bonosdescuento->rimpbonoccredito * $cotiventa;
                                        }
                                        if ($stock->estado == 'RECUPERADO') {
                                            $bono_a = $bonosdescuento->recbonoacredito * $cotiventa;
                                            $bono_b = $bonosdescuento->recbonobcredito * $cotiventa;
                                            $bono_c = $bonosdescuento->recbonoccredito * $cotiventa;
                                        }
                                    } else {
                                        if ($stock->estado == 'USADO') {
                                            $bono_a = $bonosdescuento->usabonoacreditofuera * $cotiventa;
                                            $bono_b = $bonosdescuento->usabonobcreditofuera * $cotiventa;
                                            $bono_c = $bonosdescuento->usabonoccreditofuera * $cotiventa;
                                        }
                                        if ($stock->estado == 'RECIEN IMPORTADO') {
                                            $bono_a = $bonosdescuento->rimpbonoacreditofuera * $cotiventa;
                                            $bono_b = $bonosdescuento->rimpbonobcreditofuera * $cotiventa;
                                            $bono_c = $bonosdescuento->rimpbonoccreditofuera * $cotiventa;
                                        }
                                        if ($stock->estado == 'RECUPERADO') {
                                            $bono_a = $bonosdescuento->recbonoacreditofuera * $cotiventa;
                                            $bono_b = $bonosdescuento->recbonobcreditofuera * $cotiventa;
                                            $bono_c = $bonosdescuento->recbonoccreditofuera * $cotiventa;
                                        }
                                    }

                                    $cantidaddebonoliberado = 0;
                                    $bonoliberado = 0;
                                    if ($bono > 0) { //cargo bono
                                        if ($bono >= $bono_a) {
                                            if ($bono == $bono_a) {
                                                $bonoliberado = $bono_a;
                                                $cantidaddebonoliberado = 1;
                                            } else {
                                                if ($bono >= ($bono_a + $bono_b)) {
                                                    if ($bono == ($bono_a + $bono_b)) {
                                                        $bonoliberado = $bono;
                                                        $cantidaddebonoliberado = 2;
                                                    } else {
                                                        if ($bono >= ($bono_a + $bono_b + $bono_c)) {
                                                            if ($bono == ($bono_a + $bono_b + $bono_c)) {
                                                                $bonoliberado = $bono;
                                                                $cantidaddebonoliberado = 3;
                                                            } else {
                                                                $bonoliberado = $bono_a + $bono_b + $bono_c;
                                                                $cantidaddebonoliberado = 3;
                                                            }
                                                        } else {
                                                            $bonoliberado = $bono;
                                                            $cantidaddebonoliberado = 3;
                                                        }
                                                    }
                                                } else {
                                                    $bonoliberado = $bono;
                                                    $cantidaddebonoliberado = 2;
                                                }
                                            }
                                        } else {
                                            $bonoliberado = $bono;
                                            $cantidaddebonoliberado = 1;
                                        }
                                    }

                                    $this->agregarbononuevo(trim($stock->chasis), $stock->id, $plazo, $moneda, $totalguaranies, $totalentrega, $saldoguarani, $cantidadcuota, $montocuota, $cantidadrefuerzo, $refuerzo, $this->Auth->User('empleado'), date('d-m-Y'), date('H-i-s'), 0, 0, $bonoliberado, $fueradentro, $condicion, $entrega, $entregave, $cambalache, $aumentar, $color, $llanta, $interior, $equipamiento, $camara, $buscahuella, $bono,  $cantidaddebonoliberado, $ci, $telefono);

                                    $total = $total - $bonoliberado;
                                    $saldo = $total - $totalentrega;

                                    $saldoguarani = ($saldo * ($cotiventa + 50));
                                    $totalguaranies = $saldoguarani + $totalentrega;

                                    $cantidadcuota = $cuota - $cantidadrefuerzo;
                                    $montocuota = ($saldoguarani - ($cantidadrefuerzo * $refuerzo)) / $cantidadcuota;

                                    $ver = 1;

                                    $info = array('Guaranies', $totalguaranies, $totalentrega, $saldoguarani, $cantidadcuota, $montocuota, $cantidadrefuerzo, $refuerzo,  $this->property, $bono, $bonoliberado);
                                    $this->set('info', $info);

                                    $Simulador = TableRegistry::get('simuladorVentas');
                                    $simulador = $Simulador->get($this->property);
                                    $this->set('simuladorVenta', $simulador);
                                } // FIN CANT REFUERZO
                            } else {
                                $this->Flash->error("LAS ENTREGA NO PUEDEN SER MENOR A: " . (($stock->entregaminima - $precios->menosentrega) * $cotiventa) . " GUARANIES ");
                            } // RESTA ENTREGA
                        }
                    } else {
                        $this->Flash->error("LAS ENTREGAS NO PUEDEN SER VACIAS!");
                    } // FIN TOTAL
                } else {
                    $this->Flash->error("SELECCIONE UNA CUOTA!");
                } // FIN TOTAL

                $this->set('ver', $ver);
                $this->set('precios', $precios);
                $this->set('bonosdescuento', $bonosdescuento);
                $this->set('cotiventa', $cotiventa);
                $this->set('coticompra', $coticompra);
            }

            //  $this->set(compact('stock'));
            //  $this->set('_serialize', ['stock']);
        }
    }

    private $property = 0;

    function saberid()
    {
        $this->property = 1993;
        //$this->$simulador_variable = 1000;
        return true;
    }

    public function quitarfotos($chasis = null)
    {

        $connection = ConnectionManager::get('default');
        $connection->execute('UPDATE imagenapps SET mostrar = ? WHERE chasis = ?', [1, $chasis]);
        $connection->execute('UPDATE productos SET pro_imagenapp = ? WHERE pro_codori = ?', ['', $chasis]);
        $connection->commit();
        $connection->disconnect();

        echo "<script>history.go(-1)</script>";
    }


    function agregarbononuevo($chasis, $producto_id, $meses, $moneda, $total, $entrega, $saldo, $cuota, $montocuota, $refuerzo, $montorefuerzo, $empleado_id, $fecha, $hora, $tipopersona, $aleatorio, $totalbono, $fueradentro, $condicion, $efe, $vehi, $camba, $aumentar, $color, $llanta, $interior, $equipamiento, $camara, $buscahuella,  $prop_bono, $veces, $ci, $telefono)
    {


        $query = TableRegistry::get('simulador_ventas')->query();

        $query->insert(['chasis', 'producto_id', 'meses', 'moneda', 'total', 'entrega', 'saldo', 'cuota', 'montocuota', 'refuerzo', 'montorefuerzo', 'empleado_id', 'fecha', 'hora', 'tipopersona', 'ci', 'telefono', 'aleatorio', 'veces', 'vecesgerente', 'vecessergio', 'estado', 'borrado', 'confirmado', 'totalbono', 'fueradentro', 'condicion', 'efectivo', 'vehiculo', 'cambalache', 'aumentar', 'color', 'llanta', 'interior', 'equipamiento', 'camara', 'buscahuella', 'prop_bono'])->values([

            'chasis' => $chasis,
            'producto_id' => $producto_id,
            'meses' => $meses,
            'moneda' => $moneda,
            'total' => $total,
            'entrega' => $entrega,
            'saldo' => $saldo,
            'cuota' => $cuota,
            'montocuota' => $montocuota,
            'refuerzo' => $refuerzo,
            'montorefuerzo' => $montorefuerzo,
            'empleado_id' => $empleado_id,
            'fecha' => str_replace("-", "/", $fecha),
            'hora' => str_replace("-", ":", $hora),
            'tipopersona' => $tipopersona,
            'ci' => $ci,
            'telefono' => $telefono,
            'aleatorio' => $aleatorio,
            'veces' => $veces,
            'vecesgerente' => 0,
            'vecessergio' => 0,
            'estado' => 1,
            'borrado' => 0,
            'confirmado' => 0,
            'totalbono' => $totalbono,
            'fueradentro' => $fueradentro,
            'condicion' => $condicion,
            'efectivo' => $efe,
            'vehiculo' => $vehi,
            'cambalache' => $camba,
            'aumentar' => $aumentar,
            'color' => $color,
            'llanta' => $llanta,
            'interior' => $interior,
            'equipamiento' => $equipamiento,
            'camara' => $camara,
            'buscahuella' => $buscahuella,
            'prop_bono' => $prop_bono

        ])->execute();

        $simulador = TableRegistry::get('simulador_ventas');
        $querys = $simulador
            ->find()
            ->select(['id'])
            ->where([
                'chasis' => $chasis,
                'producto_id' => $producto_id,
                'meses' => $meses,
                'moneda' => $moneda,
                'total' => $total,
                'entrega' => $entrega,
                'saldo' => $saldo,
                'cuota' => $cuota,
                'montocuota' => $montocuota,
                'refuerzo' => $refuerzo,
                'montorefuerzo' => $montorefuerzo,
                'empleado_id' => $empleado_id,
                'fecha' => str_replace("-", "/", $fecha),
                'hora' => str_replace("-", ":", $hora),
                'tipopersona' => $tipopersona,
                'ci' => $ci,
                'telefono' => $telefono,
                'aleatorio' => $aleatorio,
                'veces' => $veces,
                'vecesgerente' => 0,
                'vecessergio' => 0,
                'estado' => 1,
                'borrado' => 0,
                'confirmado' => 0,
                'totalbono' => $totalbono,
                'fueradentro' => $fueradentro,
                'condicion' => $condicion,
                'efectivo' => $efe,
                'vehiculo' => $vehi,
                'cambalache' => $camba,
                'aumentar' => $aumentar,
                'color' => $color,
                'llanta' => $llanta,
                'interior' => $interior,
                'equipamiento' => $equipamiento,
                'camara' => $camara,
                'buscahuella' => $buscahuella,
                'prop_bono' => $prop_bono
            ]);

        foreach ($querys as $bono) {
            $this->property = $bono->id;
        }

        return true;
    }


    public function enviarremates()
    {

        $conditions =  "Stocks.estado = 'USADO'";

        $stocks = $this->Stocks->find('all', ['conditions' => $conditions]);
        foreach ($stocks as $stock) :
            echo $stock->chasis;
            $query = TableRegistry::get('remates')->query();

            $query->insert(['chasis', 'modelo', 'precio', 'fecha', 'stock_id', 'costo', 'imagen', 'empresa'])->values([
                'chasis' => $stock->chasis,
                'modelo' => $stock->modelo . ' ' . $stock->ano . ' ' . $stock->color,
                'precio' => 0,
                'fecha' =>  date('d/m/Y'),
                'stock_id' => $stock->id,
                'costo' => $stock->costo,
                'imagen' => $stock->imagen,
                'empresa' => 1
            ])->execute();

        endforeach;
    }



    public function newsimulador($id = null)
    {
        $stock = $this->Stocks->get($id, []);

        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti) :
            $venta = $coti->doven;
            $compra = $coti->docom;
        endforeach;

        $this->set('cotiventa', $venta);
        $this->set('coticompra', $compra);

        $this->set(compact('stocks', 'stock'));
        $this->set('_serialize', ['stock']);
        $this->set("cotizacion", $query->first());
    }


    public function pedirbonomas($idsimulador)
    {
        $simulador = TableRegistry::get('simulador_ventas');
        $simula = $simulador->get($idsimulador, [
            'contain' => ['Stocks']
        ]);

        $Bonosdescuentos = TableRegistry::get('bonosdescuentos');
        $bonosdescuento = $Bonosdescuentos->get(1);

        /// echo $bonosdescuento;
        $bono = 0;
        $veces = 0;
        if ($simula->condicion == 1) {  // CONTADO
            if ($simula->stock->estado == 'USADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->usabonoacontado;
                        $veces = 1;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->usabonobcontado;
                        $veces = 2;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->usabonoccontado;
                        $veces = 3;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->usabonodcontado;
                        $veces = 4;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->usabonoecontado;
                        $veces = 5;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->usabonofcontado;
                        $veces = 6;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->usabonogcontado;
                        $veces = 7;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->usabonoacontadofuera;
                        $veces = 1;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->usabonobcontadofuera;
                        $veces = 2;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->usabonoccontadofuera;
                        $veces = 3;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->usabonodcontadofuera;
                        $veces = 4;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->usabonoecontadofuera;
                        $veces = 5;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->usabonofcontadofuera;
                        $veces = 6;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->usabonogcontadofuera;
                        $veces = 7;
                    }
                }
            } // FIN USADO

            if ($simula->stock->estado == 'RECIEN IMPORTADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->rimpbonoacontado;
                        $veces = 1;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->rimpbonobcontado;
                        $veces = 2;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->rimpbonoccontado;
                        $veces = 3;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->rimpbonodcontado;
                        $veces = 4;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->rimpbonoecontado;
                        $veces = 5;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->rimpbonofcontado;
                        $veces = 6;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->rimpbonogcontado;
                        $veces = 7;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->rimpbonoacontadofuera;
                        $veces = 1;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->rimpbonobcontadofuera;
                        $veces = 2;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->rimpbonoccontadofuera;
                        $veces = 3;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->rimpbonodcontadofuera;
                        $veces = 4;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->rimpbonoecontadofuera;
                        $veces = 5;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->rimpbonofcontadofuera;
                        $veces = 6;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->rimpbonogcontadofuera;
                        $veces = 7;
                    }
                }
            } // FIN RECIEN IMPORTADO
            if ($simula->stock->estado == 'RECUPERADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->recbonoacontado;
                        $veces = 1;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->recbonobcontado;
                        $veces = 2;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->recbonoccontado;
                        $veces = 3;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->recbonodcontado;
                        $veces = 4;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->recbonoecontado;
                        $veces = 5;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->recbonofcontado;
                        $veces = 6;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->recbonogcontado;
                        $veces = 7;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->recbonoacontadofuera;
                        $veces = 1;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->recbonobcontadofuera;
                        $veces = 2;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->recbonoccontadofuera;
                        $veces = 3;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->recbonodcontadofuera;
                        $veces = 4;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->recbonoecontadofuera;
                        $veces = 5;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->recbonofcontadofuera;
                        $veces = 6;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->recbonogcontadofuera;
                        $veces = 7;
                    }
                }
            } // FIN RECUPERADO

        } // FIN CONTADO

        if ($simula->condicion == 2) {  // credito
            if ($simula->stock->estado == 'USADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->usabonoacredito;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->usabonobcredito;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->usabonoccredito;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->usabonodcredito;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->usabonoecredito;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->usabonofcredito;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->usabonogcredito;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->usabonoacreditofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->usabonobcreditofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->usabonoccreditofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->usabonodcreditofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->usabonoecreditofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->usabonofcreditofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->usabonogcreditofuera;
                    }
                }
            } // FIN USADO

            if ($simula->stock->estado == 'RECIEN IMPORTADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->rimpbonoacredito;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->rimpbonobcredito;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->rimpbonoccredito;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->rimpbonodcredito;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->rimpbonoecredito;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->rimpbonofcredito;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->rimpbonogcredito;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->rimpbonoacreditofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->rimpbonobcreditofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->rimpbonoccreditofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->rimpbonodcreditofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->rimpbonoecreditofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->rimpbonofcreditofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->rimpbonogcreditofuera;
                    }
                }
            } // FIN RECIEN IMPORTADO
            if ($simula->stock->estado == 'RECUPERADO') {
                if ($simula->fueradentro == 0) {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->recbonoacredito;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->recbonobcredito;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->recbonoccredito;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->recbonodcredito;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->recbonoecredito;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->recbonofcredito;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->recbonogcredito;
                    }
                } else {
                    if ($simula->veces == 0) {
                        $bono = $bonosdescuento->recbonoacreditofuera;
                    }
                    if ($simula->veces == 1) {
                        $bono = $bonosdescuento->recbonobcreditofuera;
                    }
                    if ($simula->veces == 2) {
                        $bono = $bonosdescuento->recbonoccreditofuera;
                    }
                    if ($simula->veces == 3) {
                        $bono = $bonosdescuento->recbonodcreditofuera;
                    }
                    if ($simula->veces == 4) {
                        $bono = $bonosdescuento->recbonoecreditofuera;
                    }
                    if ($simula->veces == 5) {
                        $bono = $bonosdescuento->recbonofcreditofuera;
                    }
                    if ($simula->veces == 6) {
                        $bono = $bonosdescuento->recbonogcreditofuera;
                    }
                }
            } // FIN RECUPERADO

        } // FIN CREDITO

        if ($simula->veces == 0) {
            $sql = "UPDATE simulador_ventas SET veces=1, totalbono=totalbono + " . $bono . ", hora_bono = '" . date('H:i:s') . "' WHERE id = " . $idsimulador;
            $connection = ConnectionManager::get('default');
            $connection->execute($sql);
            $connection->commit();
            $connection->disconnect();
        }

        if ($simula->veces == 1) {
            $sql = "UPDATE simulador_ventas SET veces=2, totalbono=totalbono + " . $bono . ", hora_bono = '" . date('H:i:s') . "' WHERE id = " . $idsimulador;
            $connection = ConnectionManager::get('default');
            $connection->execute($sql);
            $connection->commit();
            $connection->disconnect();
        }

        if ($simula->veces == 2) {
            $sql = "UPDATE simulador_ventas SET veces=3, totalbono=totalbono + " . $bono . ", hora_bono = '" . date('H:i:s') . "' WHERE id = " . $idsimulador;
            $connection = ConnectionManager::get('default');
            $connection->execute($sql);
            $connection->commit();
            $connection->disconnect();
        }

        if ($simula->veces == 3) {
            $sql = "UPDATE simulador_ventas SET veces=4, totalbono=totalbono + " . $bono . ", hora_bono = '" . date('H:i:s') . "' WHERE id = " . $idsimulador;
            $connection = ConnectionManager::get('default');
            $connection->execute($sql);
            $connection->commit();
            $connection->disconnect();
        }

        if ($simula->veces == 4) {
            $sql = "UPDATE simulador_ventas SET veces=5, totalbono=totalbono + " . $bono . ", hora_bono = '" . date('H:i:s') . "' WHERE id = " . $idsimulador;
            $connection = ConnectionManager::get('default');
            $connection->execute($sql);
            $connection->commit();
            $connection->disconnect();
        }

        if ($simula->veces == 5) {
            $sql = "UPDATE simulador_ventas SET veces=6, totalbono=totalbono + " . $bono . ", hora_bono = '" . date('H:i:s') . "' WHERE id = " . $idsimulador;
            $connection = ConnectionManager::get('default');
            $connection->execute($sql);
            $connection->commit();
            $connection->disconnect();
        }

        if ($simula->veces == 6) {
            $sql = "UPDATE simulador_ventas SET veces=7, totalbono=totalbono + " . $bono . ", hora_bono = '" . date('H:i:s') . "' WHERE id = " . $idsimulador;
            $connection = ConnectionManager::get('default');
            $connection->execute($sql);
            $connection->commit();
            $connection->disconnect();
        }


        echo "<script>history.go(-1)</script>";
    }



    public function cargarcelular($chasis, $producto_id, $meses, $moneda, $total, $entrega, $saldo, $cuota, $montocuota, $refuerzo, $montorefuerzo, $empleado_id, $fecha, $hora, $tipopersona, $aleatorio, $totalbono, $fueradentro, $condicion, $efe, $vehi, $camba, $aumentar, $color, $llanta, $interior, $equipamiento, $camara, $buscahuella, $especial)
    {
        $query = TableRegistry::get('simulador_ventas')->query();

        $query->insert(['chasis', 'producto_id', 'meses', 'moneda', 'total', 'entrega', 'saldo', 'cuota', 'montocuota', 'refuerzo', 'montorefuerzo', 'empleado_id', 'fecha', 'hora', 'tipopersona', 'ci', 'telefono', 'aleatorio', 'veces', 'vecesgerente', 'vecessergio', 'estado', 'borrado', 'confirmado', 'totalbono', 'fueradentro', 'condicion', 'efectivo', 'vehiculo', 'cambalache', 'aumentar', 'color', 'llanta', 'interior', 'equipamiento', 'camara', 'buscahuella', 'precioespecial'])->values([

            'chasis' => $chasis,
            'producto_id' => $producto_id,
            'meses' => $meses,
            'moneda' => $moneda,
            'total' => $total,
            'entrega' => $entrega,
            'saldo' => $saldo,
            'cuota' => $cuota,
            'montocuota' => $montocuota,
            'refuerzo' => $refuerzo,
            'montorefuerzo' => $montorefuerzo,
            'empleado_id' => $empleado_id,
            'fecha' => str_replace("-", "/", $fecha),
            'hora' => str_replace("-", ":", $hora),
            'tipopersona' => $tipopersona,
            'ci' => '',
            'telefono' => '',
            'aleatorio' => $aleatorio,
            'veces' => 0,
            'vecesgerente' => 0,
            'vecessergio' => 0,
            'estado' => 0,
            'borrado' => 0,
            'confirmado' => 0,
            'totalbono' => $totalbono,
            'fueradentro' => $fueradentro,
            'condicion' => $condicion,
            'efectivo' => $efe,
            'vehiculo' => $vehi,
            'cambalache' => $camba,
            'aumentar' => $aumentar,
            'color' => $color,
            'llanta' => $llanta,
            'interior' => $interior,
            'equipamiento' => $equipamiento,
            'camara' => $camara,
            'buscahuella' => $buscahuella,
            'precioespecial' => $especial

        ])->execute();



        $simulador = TableRegistry::get('simulador_ventas');
        $querys = $simulador
            ->find()
            ->select(['id'])
            ->where([
                'chasis' => $chasis,
                'producto_id' => $producto_id,
                'meses' => $meses,
                'moneda' => $moneda,
                'total' => $total,
                'entrega' => $entrega,
                'saldo' => $saldo,
                'cuota' => $cuota,
                'montocuota' => $montocuota,
                'refuerzo' => $refuerzo,
                'montorefuerzo' => $montorefuerzo,
                'empleado_id' => $empleado_id,
                'fecha' =>  str_replace("-", "/", $fecha),
                'hora' => str_replace("-", ":", $hora),
                'tipopersona' => $tipopersona,
                'ci' => '',
                'telefono' => '',
                'aleatorio' => $aleatorio,
                'veces' => 0,
                'vecesgerente' => 0,
                'vecessergio' => 0,
                'estado' => 0,
                'borrado' => 0,
                'confirmado' => 0,
                'totalbono' => $totalbono,
                'fueradentro' => $fueradentro,
                'condicion' => $condicion,
                'efectivo' => $efe,
                'vehiculo' => $vehi,
                'cambalache' => $camba,
                'aumentar' => $aumentar,
                'color' => $color,
                'llanta' => $llanta,
                'interior' => $interior,
                'equipamiento' => $equipamiento,
                'camara' => $camara,
                'buscahuella' => $buscahuella
            ]);

        foreach ($querys as $bono) {
            return $this->redirect(['controller' => 'SimuladorVentas', 'action' => 'edit', $bono->id]);
        }
    }

    public function pedirbonoporcentaje($idsimulador)
    {

        $simulador = TableRegistry::get('simulador_ventas');
        $simula = $simulador->get($idsimulador, [
            'contain' => ['Stocks']
        ]);

        if ($simula->veces == 0) {

            $Bonosdescuentos = TableRegistry::get('bonosdescuentos');
            $bonosdescuento = $Bonosdescuentos->get(1);


            $cotizacions  =  TableRegistry::get('cotizacions');
            $query = $cotizacions->find('all');
            $venta = 0;
            $compra = 0;
            foreach ($query as $coti) :
                $venta = $coti->doven;
            endforeach;


            $bono = 0;
            $porcentaje = 0;
            if ($simula->meses >= 1 and $simula->meses <= 17) {
                $porcentaje = 0.03;
            }

            if ($simula->meses >= 18 and $simula->meses <= 23) {
                $porcentaje = 0.05;
            }

            if ($simula->meses >= 24 and $simula->meses <= 36) {
                $porcentaje = 0.08;
            }


            $bono = $simula->total * $porcentaje;

            if ($simula->moneda == 2) {
                $bono = $bono / $venta;
            }

            $sql = "UPDATE simulador_ventas SET veces=veces+1, totalbono=totalbono + " . $bono . ", hora_bono = '" . date('H:i:s') . "' WHERE id = " . $idsimulador;
            $connection = ConnectionManager::get('default');
            $connection->execute($sql);
            $connection->commit();
            $connection->disconnect();
        }
        if (!strstr($_SERVER['HTTP_USER_AGENT'], 'iPhone') || !strstr($_SERVER['HTTP_USER_AGENT'], 'iPod') || !strstr($_SERVER['HTTP_USER_AGENT'], 'iPad')) {
            echo "<script>history.go(-1)</script>";
        } else {
            location . reload();
        }
    }


    public function disponible($id = null)
    {
        $connectionLocal = ConnectionManager::get('local');
        $connectionDefault = ConnectionManager::get('default');

        $connectionLocal->execute('UPDATE productos SET pro_disponible= ?, pro_usuarionodisponible= ? WHERE pro_codigo = ?', [0, $this->Auth->User('id'), $id]);
        $connectionLocal->commit();
        $connectionLocal->disconnect();

        $connectionDefault->execute('UPDATE productos SET pro_disponible= ? WHERE pro_codigo = ?', [0, $id]);
        $connectionDefault->commit();
        $connectionDefault->disconnect();

        echo "<script>history.go(-1)</script>";
    }


    public function nodisponible($id = null)
    {
        $connectionLocal = ConnectionManager::get('local');
        $connectionDefault = ConnectionManager::get('default');

        $connectionLocal->execute('UPDATE productos SET pro_disponible= ?, pro_usuarionodisponible= ? WHERE pro_codigo = ?', [1, $this->Auth->User('id'), $id]);
        $connectionLocal->commit();
        $connectionLocal->disconnect();

        $connectionDefault->execute('UPDATE productos SET pro_disponible= ? WHERE pro_codigo = ?', [1, $id]);
        $connectionDefault->commit();
        $connectionDefault->disconnect();

        echo "<script>history.go(-1)</script>";
    }

    public function alto($id = null)
    {
        $this->autoRender = false;
        $connection = ConnectionManager::get('local');
        $connection->execute('UPDATE productos SET pro_estadoauto= ? WHERE pro_codigo = ?',  [3, $id]);
        $connection->commit();
        $connection->disconnect();

        echo "<script>history.go(-1)</script>";
    }


    public function medio($id = null)
    {
        $this->autoRender = false;
        $connection = ConnectionManager::get('local');
        $connection->execute('UPDATE productos SET pro_estadoauto= ? WHERE pro_codigo = ?',  [2, $id]);
        $connection->commit();
        $connection->disconnect();

        echo "<script>history.go(-1)</script>";
    }

    public function bajo($id = null)
    {
        $this->autoRender = false;
        $connection = ConnectionManager::get('local');
        $connection->execute('UPDATE productos SET pro_estadoauto= ? WHERE pro_codigo = ?',  [1, $id]);
        $connection->commit();
        $connection->disconnect();

        echo "<script>history.go(-1)</script>";
    }

    public function sincolor($id = null)
    {
        $this->autoRender = false;
        $connection = ConnectionManager::get('local');
        $connection->execute('UPDATE productos SET pro_estadoauto= ? WHERE pro_codigo = ?',  [0, $id]);
        $connection->commit();
        $connection->disconnect();

        echo "<script>history.go(-1)</script>";
    }


    public function bajoprueba($id = null)
    {
        $this->autoRender = false;

        // $connection = ConnectionManager::get('local');
        // $connection->execute('UPDATE productos SET pro_estadoauto= ? WHERE pro_codigo = ?',  [1, $id]);
        // $connection->commit();
        //  $connection->disconnect();

        echo "<script>history.go(-1)</script>";
    }

    public function ubicacion()
    {


        $this->set('ubicas', TableRegistry::get('ubicas')->find('list'));

        $search = null;
        $ubi = null;



        if (!empty($this->request->query['ubi'])) {
            $search = $this->request->query['search'];
            $ubi = $this->request->query['ubi'];

            $terms = explode(' ', trim($search));
            if ($search == null || $search == '') {
                $conditions = array('stocks.ubiid' => $ubi);
            } else {


                foreach ($terms as $term) {

                    $conditions[] = array(

                        'OR' => array(
                            array('stocks.chasis LIKE' => '%' . $term . '%'),
                            array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                            array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                            array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                        ),
                        array('stocks.ubiid' => $ubi)
                    );
                }
            }

            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            //debug($stocks); exit();
            $this->set('stocks', $this->paginate($stocks));
            $this->set('_serialize', ['stocks']);
        } else {
            $this->paginate = [
                'order' => [
                    'Stocks.modelo' => 'asc'
                ]
            ];
            $stocks = $this->paginate($this->Stocks);
            $this->set(compact('stocks'));
            $this->set('_serialize', ['stocks']);
        }

        $this->set('search', $search);
        $this->set('ubi', $ubi);
    }



    public function kilometraje()
    {
        // Monta lista de colores para pasar a la vista en kilometrage.ctp
        $colorsTable = TableRegistry::getTableLocator()->get('colors');
        $opciones = $colorsTable->find('list', ['keyField' => 'id', 'valueField' => 'descripcion'])->toArray();

        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    )
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $this->set('stocks', $this->paginate($stocks));
            $this->set('_serialize', ['stocks']);
        } else {
            $this->paginate = [
                'order' => [
                    'Stocks.modelo' => 'asc'
                ]
            ];
            $stocks = $this->paginate($this->Stocks);
            $this->set(compact('stocks'));
            $this->set('_serialize', ['stocks']);
        }
        $this->set('opciones', $opciones);
    }

    // En el controlador StocksController.php

    public function addkilometraje()
    {

        $this->render(false);

        if ($this->request->is('post')) {
            $stockId = $this->request->getData("id");

            $kilometraje = $this->request->getData("kilometraje");

            $sql = "UPDATE productos SET pro_kilometraje='" . $kilometraje . "' WHERE pro_codigo=" . $stockId;

            $connection = ConnectionManager::get('default');
            $connection->execute($sql);
            $connection->commit();
            $connection->disconnect();

            // Si la lógica de guardado fue exitosa
            $response = ['success' => true];
            echo json_encode($response);
        } else {
            // Si la solicitud no es una petición AJAX
            $response = ['success' => false];
            echo json_encode($response);
        }
    }

    public function addtipollanta()
    {
        $this->render(false);
        if ($this->request->is('post')) {
            $stockId = $this->request->getData("id");
            $tipollanta = $this->request->getData("tipollanta");
            $sql = "UPDATE productos SET pro_tipollanta='" . $tipollanta . "' WHERE pro_codigo=" . $stockId;
            $connection = ConnectionManager::get('default');
            $connection->execute($sql);
            $connection->commit();
            $connection->disconnect();
            // Si la lógica de guardado fue exitosa
            $response = ['success' => true];
            echo json_encode($response);
        } else {
            // Si la solicitud no es una petición AJAX
            $response = ['success' => false];
            echo json_encode($response);
        }
    }

    public function addcambiocolor()
    {
        $this->render(false);
        if ($this->request->is('post')) {
            $stockId = $this->request->getData("id");
            $stockChasis = $this->request->getData("chasis");
            $color = $this->request->getData("color");
            $sql = "UPDATE vehiculo SET ve_color=" . $color . " WHERE ve_detprod='" . $stockChasis . "'";
            $connection = ConnectionManager::get('default');
            $connection->execute($sql);
            $connection->commit();
            $connection->disconnect();
            // Si la lógica de guardado fue exitosa
            $response = ['success' => true];
            echo json_encode($response);
        } else {
            // Si la solicitud no es una petición AJAX
            $response = ['success' => false];
            echo json_encode($response);
        }
    }



    public function lista()
    {
        $Stocktodos = TableRegistry::get('stocktodos');

        $consulta = $Stocktodos->find()
            ->select(['lista' => $Stocktodos->query()->func()->concat([
                'marca' => 'identifier',
                ' ',
                'modelo' => 'identifier'
            ])])
            ->group(['marca', 'modelo'])
            ->order(['marca', 'modelo']);



        $precioespecials = TableRegistry::get('precioespecials')->newEntity();

        if ($this->request->is('post')) {


            $precioespecials = TableRegistry::get('precioespecials')->patchEntity($precioespecials, $this->request->data);

            $precioespecials->usuario = $this->Auth->User('id');

            $hoy = getdate();
            $fecha = $hoy['mday'] . "/" . $hoy['mon'] . "/" . $hoy['year'];

            $precioespecials->fecha = $fecha;
            $precioespecials->hora = date("H:i:s");

            if (TableRegistry::get('precioespecials')->save($precioespecials)) {
                $this->Flash->success('Agregado correctamente!');

                return $this->redirect(['action' => 'listadoprecio']);
            }
        }

        $this->set('resultadoConsulta', $consulta);
        $this->set('precioespecials', $precioespecials);
    }

    public function listadoprecio()
    {

        $precioespecials = TableRegistry::get('precioespecials');

        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));
            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    array('modelo LIKE' => '%' . strtoupper($term) . '%'),
                );
            }
            $stocks = $precioespecials->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['modelo' => 'asc']));
            $this->paginate = [
                'limit' => 30,
                'order' => ['modelo' => 'ASC'],
            ];
            $this->set('precioespecials', $this->paginate($stocks));
        } else {
            $query = $precioespecials->find('all');
            $this->paginate = [
                'limit' => 30,
                'order' => ['modelo' => 'ASC'],
            ];
            $this->set('precioespecials', $this->paginate($query));
        }
        $this->set('search', $search);
    }

    public function editarprecio($id = null)
    {
        $Stocktodos = TableRegistry::get('stocktodos');
        $consulta = $Stocktodos->find()
            ->select(['lista' => $Stocktodos->query()->func()->concat([
                'marca' => 'identifier',
                ' ',
                'modelo' => 'identifier'
            ])])
            ->group(['marca', 'modelo'])
            ->order(['marca', 'modelo']);

        $precioespecials = TableRegistry::get('precioespecials')->get($id, []);

        if ($this->request->is(['patch', 'post', 'put'])) {
            $precioespecials = TableRegistry::get('precioespecials')->patchEntity($precioespecials, $this->request->data);

            $hoy = getdate();
            $fecha = $hoy['mday'] . "/" . $hoy['mon'] . "/" . $hoy['year'];

            $precioespecials->fecha = $fecha;
            $precioespecials->hora = date("H:i:s");
            $precioespecials->usuario = $this->Auth->User('id');

            if (TableRegistry::get('precioespecials')->save($precioespecials)) {
                $this->Flash->success('Modificado correctamente!');
                return $this->redirect(['action' => 'listadoprecio']);
            }
        }

        $this->set('resultadoConsulta', $consulta);
        $this->set('precioespecials', $precioespecials);
    }

    public function borrarprecio($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $precioespecials = TableRegistry::get('precioespecials')->get($id, []);
        $hoy = getdate();
        $fecha = $hoy['mday'] . "/" . $hoy['mon'] . "/" . $hoy['year'];

        $precioespecials->fecha = $fecha;
        $precioespecials->hora = date("H:i:s");
        $precioespecials->usuario = $this->Auth->User('id');

        if (TableRegistry::get('precioespecials')->save($precioespecials)) {
            if (TableRegistry::get('precioespecials')->delete($precioespecials)) {
                $this->Flash->success('Eliminado correctamente!');
            } else {
                $this->Flash->error('No se pudo eliminar. Favor, intente nuevamente.');
            }
        }

        return $this->redirect(['action' => 'listadoprecio']);
    }

    public function verprecio($id = null)
    {
        $precioespecials = TableRegistry::get('precioespecials')->get($id, []);
        $this->set('stock', $precioespecials);
    }


    public function simuladorespecial($id = null)
    {
        $stock = $this->Stocks->get($id, []);

        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti) :
            $venta = $coti->doven;
            $compra = $coti->docom;
        endforeach;

        $precioespecials = TableRegistry::get('precioespecials');
        $precioEspecial = $precioespecials
            ->find()
            ->where([
                'modelo' => $stock->modelo,
                'anio_desde <=' => $stock->ano,
                'anio_hasta >=' => $stock->ano
            ])
            ->first();


        $this->set('cotiventa', $venta);
        $this->set('coticompra', $compra);

        $this->set('precioespecial', $precioEspecial);

        $this->set(compact('stocks', 'stock'));
        $this->set('_serialize', ['stock']);
        $this->set("cotizacion", $query->first());
    }

    public function colorchange($tipo = null, $id = null)
    {
        $this->render(false);
        if ($this->request->is('post')) {
            $sql = "UPDATE productos SET pro_colorido='" . $tipo . "' WHERE pro_codigo=" . $id;
            $connection = ConnectionManager::get('default');
            $connection->execute($sql);
            $connection->commit();
            $connection->disconnect();
            echo "<script>history.go(-1)</script>";
        }
    }

    // lm
    public function techoPanoramico($tipo = null, $id = null)
    {
        $this->render(false);
        if ($this->request->is('post')) {
            $sql = "UPDATE productos SET pro_techo_panoramico='" . $tipo . "' WHERE pro_codigo=" . $id;
            $connection = ConnectionManager::get('default');
            $connection->execute($sql);
            $connection->commit();
            $connection->disconnect();
            echo "<script>history.go(-1)</script>";
        }
    }
    // lm

    public function cuotasvarias($id = null)
    {
        $stock = $this->Stocks->get($id, []);

        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti) :
            $venta = $coti->doven;
            $compra = $coti->docom;
        endforeach;

        $precioespecials = TableRegistry::get('preciocreditos');
        $precioEspecial = $precioespecials
            ->find()
            ->where([
                'modelo' => $stock->modelo,
                'ano_desde <=' => $stock->ano,
                'ano_hasta >=' => $stock->ano,
                'carroceria' => $stock->carroceria,
                'borrado' => 0
            ])
            ->first();


        $this->set('cotiventa', $venta);
        $this->set('coticompra', $compra);

        $this->set('preciocreditos', $precioEspecial);

        //  print_r($precioEspecial);
        //  exit();

        $this->set(compact('stocks', 'stock'));
        $this->set('_serialize', ['stock']);
        $this->set("cotizacion", $query->first());
    }

    public function cuotasvarias2($id = null)
    {
        $stock = $this->Stocks->get($id, []);

        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti) :
            $venta = $coti->doven;
            $compra = $coti->docom;
        endforeach;

        $precioespecials = TableRegistry::get('preciocreditos');
        $precioEspecial = $precioespecials
            ->find()
            ->where([
                'modelo' => $stock->modelo,
                'ano_desde <=' => $stock->ano,
                'ano_hasta >=' => $stock->ano,
                'borrado' => 0
            ])
            ->first();


        $this->set('cotiventa', $venta);
        $this->set('coticompra', $compra);

        $this->set('preciocreditos', $precioEspecial);

        //  print_r($precioEspecial);
        //  exit();

        $this->set(compact('stocks', 'stock'));
        $this->set('_serialize', ['stock']);
        $this->set("cotizacion", $query->first());
    }

    public function pilar()
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 \-]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    ),
                    array('stocks.ubiid' => 62)
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $this->set('stocks', $this->paginate($stocks));
            $this->set('_serialize', ['stocks']);
        } else {
            $this->paginate = [
                'conditions' => [
                    'Stocks.ubiid' => 62
                ],
                'order' => [
                    'stocks.modelo' => 'asc'
                ]
            ];
            $this->set('stocks', $this->paginate($this->Stocks));
            $this->set('_serialize', ['stocks']);
        }
        $this->set('search', $search);
    }


    public function terminado($id = null)
    {
        $this->autoRender = false;

        $currentDate = date("d/m/Y");
        $sql = "UPDATE productos SET pro_terminado=1, pro_fechaterminado='" . $currentDate . "' WHERE pro_codigo=" . $id;
        $connection = ConnectionManager::get('default');
        $connection->execute($sql);
        $connection->commit();
        $connection->disconnect();
        echo "<script>history.go(-1)</script>";
    }

    public function modinfo($id = null)
    {
        $stock = $this->Stocks->get($id);

        if ($this->request->is(['patch', 'post', 'put'])) {
            $stock = $this->Stocks->patchEntity($stock, $this->request->data);

            $sql = "UPDATE productos SET pro_carroceria=" . $stock->carroceria . ",  pro_traccion=" . $stock->traccion . ", pro_combustible=" . $stock->combustible . ", pro_motor='" . $stock->motor . "', pro_kilometraje = '" . $stock->kilometraje . "' WHERE pro_codigo=" . $id;

            $connection = ConnectionManager::get('default');
            $connection->execute($sql);
            $connection->commit();
            $connection->disconnect();
            echo "<script>history.go(-2)</script>";
        }

        $this->set('stock', $stock);
    }

    public function lugar($ubi = null)
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 \-]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    ),
                    array('stocks.ubiid' => $ubi)
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $this->set('stocks', $this->paginate($stocks));
            $this->set('_serialize', ['stocks']);
        } else {
            $this->paginate = [
                'conditions' => [
                    'Stocks.ubiid' => $ubi
                ],
                'order' => [
                    'stocks.modelo' => 'asc'
                ]
            ];
            $this->set('stocks', $this->paginate($this->Stocks));
            $this->set('_serialize', ['stocks']);
        }

        $ubiVO = TableRegistry::get('ubicas');
        $ubica = $ubiVO->get($ubi);

        $this->set('search', $search);
        $this->set('ubi', $ubi);
        $this->set('lugar', $ubica);
    }

    public function cuotasvarias3($id = null)
    {
        $stock = $this->Stocks->get($id, []);

        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti) :
            $venta = $coti->doven;
            $compra = $coti->docom;
        endforeach;

        $precioespecials = TableRegistry::get('preciocreditos');
        $precioEspecial = $precioespecials
            ->find()
            ->where([
                'modelo' => $stock->modelo,
                'ano_desde <=' => $stock->ano,
                'ano_hasta >=' => $stock->ano,
                'carroceria' => $stock->carroceria,
                'borrado' => 0
            ])
            ->first();


        $this->set('cotiventa', $venta);
        $this->set('coticompra', $compra);

        $this->set('preciocreditos', $precioEspecial);

        //  print_r($precioEspecial);
        //  exit();

        $this->set(compact('stocks', 'stock'));
        $this->set('_serialize', ['stock']);
        $this->set("cotizacion", $query->first());
    }

    public function cuotas($id = null)
    {
        $stock = $this->Stocks->get($id, []);

        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti) :
            $venta = $coti->doven;
            $compra = $coti->docom;
        endforeach;

        $precioespecials = TableRegistry::get('preciocreditos');
        $precioEspecial = $precioespecials
            ->find()
            ->where([
                'modelo' => $stock->modelo,
                'ano_desde <=' => $stock->ano,
                'ano_hasta >=' => $stock->ano,
                'carroceria' => $stock->carroceria,
                'borrado' => 0
            ])
            ->first();

        $this->set('cotiventa', $venta);
        $this->set('coticompra', $compra);

        $this->set('preciocreditos', $precioEspecial);

        //  print_r($precioEspecial);
        //  exit();

        $this->set(compact('stocks', 'stock'));
        $this->set('_serialize', ['stock']);
        $this->set("cotizacion", $query->first());
    }

    public function guardarX()
    {
        print_r($this->request->query);
        //       print_r($_SESSION);
        print_r($_SESSION['User']);

        exit();
        //crear tabla
    }

    // luismoran: 06/05/2024
    public function miniatura($archivo = null, $local = null, $ancho = null, $alto = null)
    {
        // Separar el nombre y la extensión del archivo
        $arrNombre = explode(".", $local);
        $nombre = $arrNombre[0];
        $extension = $arrNombre[1];
        // Crear una nueva imagen a partir del archivo original
        if ($extension == "jpg" || $extension == "jpeg") $nuevo = imagecreatefromjpeg($archivo);
        elseif ($extension == "png") $nuevo = imagecreatefrompng($archivo);
        elseif ($extension == "gif") $nuevo = imagecreatefromgif($archivo);
        // Crear un thumbnail vacío con las dimensiones especificadas
        $thumb = imagecreatetruecolor($ancho, $alto);
        // Capturar las dimensiones del archivo original
        $ancho_original = imagesx($nuevo);
        $alto_original = imagesy($nuevo);
        // Rellenar el thumbnail con la imagen redimensionada
        imagecopyresampled($thumb, $nuevo, 0, 0, 0, 0, $ancho, $alto, $ancho_original, $alto_original);
        // Definir el nombre del thumbnail
        $thumb_name = "$nombre.$extension";
        // Exportar el thumbnail al formato elegido
        if ($extension == "jpg" || $extension == "jpeg") imagejpeg($thumb, $thumb_name, 76);
        elseif ($extension == "png") imagepng($thumb, $thumb_name);
        elseif ($extension == "gif") imagegif($thumb, $thumb_name);
    }
    // luismoran

    // richard
    public function sucursal($ubi = null)
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 \-]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 ]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . $term . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    ),
                    array('stocks.ubisucursal' => $ubi)
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $this->set('stocks', $this->paginate($stocks));
            $this->set('_serialize', ['stocks']);
        } else {
            $this->paginate = [
                'conditions' => [
                    'Stocks.ubisucursal' => $ubi
                ],
                'order' => [
                    'stocks.modelo' => 'asc'
                ]
            ];
            $this->set('stocks', $this->paginate($this->Stocks));
            $this->set('_serialize', ['stocks']);
        }

        $ubiVO = TableRegistry::get('depositos');
        $ubica = $ubiVO->get($ubi, []);

        $this->set('search', $search);
        $this->set('ubi', $ubi);
        $this->set('lugar', "");
        $this->set('lugar2', $ubica);
    }
    // richard


    public function senadosempresa()
    {
        $search = null;
        if (!empty($this->request->query['search'])) {
            $search = $this->request->query['search'];
            $search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $search);
            $terms = explode(' ', trim($search));
            $terms = array_diff($terms, array(''));

            foreach ($terms as $term) {
                $terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 -]/u', '', $term);
                $conditions[] = array(
                    'OR' => array(
                        array('stocks.chasis LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.modelo LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.color LIKE' => '%' . strtoupper($term) . '%'),
                        array('stocks.ano LIKE' => '%' . strtoupper($term) . '%'),
                    ),
                    array('Stocks.sena' => 'SI', 'Stocks.clientesena' => '3174238')
                );
            }
            $stocks = $this->Stocks->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200, 'order' => ['Stocks.modelo' => 'asc']));
            $this->set('stocks', $this->paginate($stocks));
            $this->set('_serialize', ['stocks']);
        } else {

            $this->paginate = [
                'conditions' => [
                    'Stocks.sena' => 'SI',
                    'Stocks.clientesena' => '3174238'
                ],
                'order' => [
                    'Stocks.modelo' => 'asc'
                ]
            ];
            $this->set('stocks', $this->paginate($this->Stocks));
            $this->set('_serialize', ['stocks']);
        }

        $this->set('search', $search);
    }


    public function aggremovesena($chasis = null, $tipo = null)
    {

        if ($tipo == 1) {  //aca agrega

            $timezone = 'America/Asuncion';
            $now = Time::now($timezone);
            $futureDate = $now->addMonths(2);
            $formattedDate = $futureDate->format('d/m/Y');

            $connection = ConnectionManager::get('default');
            $connection->execute('UPDATE productos SET pro_sena=?, pro_cantidadsena=?, pro_clientesena=?, pro_monedasena=?, pro_diasenha=?, pro_vencimientosena=? where pro_codori=?', [1, 1, '3174238', 1, 1, $formattedDate, $chasis]);
            $connection->commit();
            $connection->disconnect();

            $connection2 = ConnectionManager::get('local');
            $connection2->execute('UPDATE productos SET pro_sena=?, pro_cantidadsena=?, pro_clientesena=?, pro_monedasena=?, pro_diasenha=?, pro_vencimientosena=? where pro_codori=?', [1, 1, '3174238', 1, 1, $formattedDate, $chasis]);
            $connection2->commit();
            $connection2->disconnect();
        } else { //aca quitar
            $connection = ConnectionManager::get('default');
            $connection->execute('UPDATE productos SET pro_sena=?, pro_cantidadsena=?, pro_clientesena=?, pro_monedasena=?, pro_diasenha=?, pro_vencimientosena=? where pro_codori=?', [0, 0, '', 0, 0, '', $chasis]);
            $connection->commit();
            $connection->disconnect();

            $connection2 = ConnectionManager::get('local');
            $connection2->execute('UPDATE productos SET pro_sena=?, pro_cantidadsena=?, pro_clientesena=?, pro_monedasena=?, pro_diasenha=?, pro_vencimientosena=? where pro_codori=?', [0, 0, '', 0, 0, '', $chasis]);
            $connection2->commit();
            $connection2->disconnect();
        }

        return $this->redirect($this->referer());
    }



    public function prioridadsena()
    {
        // Obtener todos los registros que cumplen con la condición
        $stocks = $this->Stocks->find('all', [
            'conditions' => [
                'Stocks.sena' => 'SI',
            ],
            'order' => [
                'Stocks.modelo' => 'asc'
            ]
        ]);

        // Filtrar por prioridad
        $prioridades = [
            'Alta' => [],
            'Media' => [],
            'Baja' => [],
        ];

        foreach ($stocks as $stock) {
            if ($stock->prioridadsena === 3) {
                $prioridades['Alta'][] = $stock;
            } elseif ($stock->prioridadsena === 2) {
                $prioridades['Media'][] = $stock;
            } else {
                $prioridades['Baja'][] = $stock;
            }
        }

        // Setear las variables para la vista
        $this->set('prioridades', $prioridades);
        $this->set('_serialize', ['prioridades']);
    }
}
