<?php
namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * Bonos Model
 *
 * @property \App\Model\Table\StocksTable|\Cake\ORM\Association\BelongsTo $Stocks
 * @property \App\Model\Table\EmpleadosTable|\Cake\ORM\Association\BelongsTo $Empleados
 *
 * @method \App\Model\Entity\Bono get($primaryKey, $options = [])
 * @method \App\Model\Entity\Bono newEntity($data = null, array $options = [])
 * @method \App\Model\Entity\Bono[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\Bono|bool save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Bono|bool saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Bono patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\Bono[] patchEntities($entities, array $data, array $options = [])
 * @method \App\Model\Entity\Bono findOrCreate($search, callable $callback = null, $options = [])
 */
class BonosTable extends Table
{

    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config)
    {
        parent::initialize($config);

        $this->setTable('bonos');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');

        $this->belongsTo('Stocks', [
            'foreignKey' => 'stock_id'
        ]);
        $this->belongsTo('Empleados', [
            'foreignKey' => 'empleado_id'
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator)
    {
        $validator
            ->integer('id')
            ->allowEmpty('id', 'create');

        $validator
            ->integer('estado')
            ->allowEmpty('estado');

        $validator
            ->integer('moneda')
            ->allowEmpty('moneda');

        $validator
            ->numeric('monto')
            ->allowEmpty('monto');

        $validator
            ->scalar('telefono')
            ->maxLength('telefono', 200)
            ->allowEmpty('telefono');

        $validator
            ->scalar('cedula')
            ->maxLength('cedula', 200)
            ->allowEmpty('cedula');

        $validator
            ->scalar('fecha')
            ->maxLength('fecha', 10)
            ->allowEmpty('fecha');

        $validator
            ->scalar('hora')
            ->maxLength('hora', 10)
            ->allowEmpty('hora');

        $validator
            ->integer('activo')
            ->allowEmpty('activo');

        return $validator;
    }

    /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules)
    {
        $rules->add($rules->existsIn(['stock_id'], 'Stocks'));
        $rules->add($rules->existsIn(['empleado_id'], 'Empleados'));

        return $rules;
    }
}
